@@ -214,6 +214,12 @@ ANYSCALE_IAM_PERMISSIONS_SERVICE_STEADY_STATE = {
             ],
             "Resource": "*",
         },
+        {
+            "Sid": "EC2Describe",
+            "Action": ["ec2:DescribeVpcs", "ec2:DescribeInternetGateways"],
+            "Effect": "Allow",
+            "Resource": "*",
+        },
         {
             "Sid": "ELBDescribe",
             "Effect": "Allow",
@@ -221,8 +227,10 @@ ANYSCALE_IAM_PERMISSIONS_SERVICE_STEADY_STATE = {
                 # Describe ELB state information
                 "elasticloadbalancing:DescribeListeners",
                 "elasticloadbalancing:DescribeLoadBalancers",
+                "elasticloadbalancing:DescribeLoadBalancerAttributes",
                 "elasticloadbalancing:DescribeRules",
                 "elasticloadbalancing:DescribeTargetGroups",
+                "elasticloadbalancing:DescribeTargetGroupAttributes",
                 "elasticloadbalancing:DescribeTargetHealth",
                 "elasticloadbalancing:DescribeListenerCertificates",
             ],
@@ -268,20 +276,26 @@ ANYSCALE_IAM_PERMISSIONS_SERVICE_STEADY_STATE = {
             "Action": [
                 # Modify ELB
                 "elasticloadbalancing:AddTags",
+                "elasticloadbalancing:RemoveTags",
                 "elasticloadbalancing:CreateRule",
                 "elasticloadbalancing:ModifyRule",
                 "elasticloadbalancing:DeleteRule",
-                "elasticloadbalancing:ModifyLoadBalancerAttributes",
+                "elasticloadbalancing:SetRulePriorities",
                 "elasticloadbalancing:CreateListener",
                 "elasticloadbalancing:ModifyListener",
                 "elasticloadbalancing:DeleteListener",
                 "elasticloadbalancing:CreateLoadBalancer",
                 "elasticloadbalancing:DeleteLoadBalancer",
+                "elasticloadbalancing:ModifyLoadBalancerAttributes",
                 "elasticloadbalancing:CreateTargetGroup",
                 "elasticloadbalancing:ModifyTargetGroup",
                 "elasticloadbalancing:DeleteTargetGroup",
+                "elasticloadbalancing:ModifyTargetGroupAttributes",
                 "elasticloadbalancing:RegisterTargets",
                 "elasticloadbalancing:DeregisterTargets",
+                "elasticloadbalancing:SetIpAddressType",
+                "elasticloadbalancing:SetSecurityGroups",
+                "elasticloadbalancing:SetSubnets",
             ],
             "Resource": "*",
             "Condition": {
