@@ -12,7 +12,10 @@ from anyscale.aws_iam_policies import (
     get_anyscale_aws_iam_assume_role_policy,
     get_anyscale_iam_permissions_ec2_restricted,
 )
-from anyscale.cli_logger import BlockLogger
+from anyscale.cli_logger import CloudSetupLogger
+from anyscale.client.openapi_client.models.cloud_analytics_event_cloud_resource import (
+    CloudAnalyticsEventCloudResource,
+)
 from anyscale.client.openapi_client.models.create_cloud_resource import (
     CreateCloudResource,
 )
@@ -26,7 +29,9 @@ from anyscale.util import (  # pylint:disable=private-import
     contains_control_plane_role,
     filter_actions_associated_with_role,
     filter_actions_from_policy_document,
+    verify_data_plane_role_assume_role_policy,
 )
+from anyscale.utils.cloud_utils import CloudSetupError
 from anyscale.utils.network_verification import (
     AWS_SUBNET_CAPACITY,
     AWS_VPC_CAPACITY,
@@ -60,9 +65,22 @@ def compare_dicts_diff(d1: Dict[Any, Any], d2: Dict[Any, Any]) -> str:
     )
 
 
+AWS_RESOURCE_DICT: Dict[str, CloudAnalyticsEventCloudResource] = {
+    "VPC": CloudAnalyticsEventCloudResource.AWS_VPC,
+    "Subnet": CloudAnalyticsEventCloudResource.AWS_SUBNET,
+    "Security group": CloudAnalyticsEventCloudResource.AWS_SECURITY_GROUP,
+    "S3 bucket": CloudAnalyticsEventCloudResource.AWS_S3_BUCKET,
+    "EFS": CloudAnalyticsEventCloudResource.AWS_EFS,
+    "CloudFormation stack": CloudAnalyticsEventCloudResource.AWS_CLOUDFORMATION,
+}
+
+
 def log_resource_not_found_error(
-    resource_name: str, resource_id: str, logger: BlockLogger
+    resource_name: str, resource_id: str, logger: CloudSetupLogger
 ) -> None:
+    resource = AWS_RESOURCE_DICT.get(resource_name, None)
+    if resource:
+        logger.log_resource_error(resource, CloudSetupError.RESOURCE_NOT_FOUND)
     logger.error(
         f"Could not find {resource_name} with id {resource_id}. Please validate that you're using the correct AWS account/credentials and that the resource values are correct"
     )
@@ -71,12 +89,16 @@ def log_resource_not_found_error(
 def verify_aws_vpc(
     cloud_resource: CreateCloudResource,
     boto3_session: boto3.Session,
-    logger: BlockLogger,
+    logger: CloudSetupLogger,
     ignore_capacity_errors: bool = False,  # TODO: Probably don't do this forever. Its kinda hacky
     strict: bool = False,  # strict is currently unused # noqa: ARG001
 ) -> bool:
     logger.info("Verifying VPC ...")
     if not cloud_resource.aws_vpc_id:
+        logger.log_resource_error(
+            CloudAnalyticsEventCloudResource.AWS_VPC,
+            CloudSetupError.MISSING_CLOUD_RESOURCE_ID,
+        )
         logger.error("Missing VPC id.")
         return False
 
@@ -90,23 +112,25 @@ def verify_aws_vpc(
         if e.response["Error"]["Code"] == "InvalidVpcID.NotFound":
             log_resource_not_found_error("VPC", cloud_resource.aws_vpc_id, logger)
             return False
+        else:
+            logger.log_resource_exception(CloudAnalyticsEventCloudResource.AWS_VPC, e)
         raise e
 
     # Verify that the VPC has "enough" capacity.
-    if (
-        AWS_VPC_CAPACITY.verify_network_capacity(
-            cidr_block_str=vpc.cidr_block, resource_name=vpc.id, logger=logger
-        )
-        or ignore_capacity_errors
+    if ignore_capacity_errors or AWS_VPC_CAPACITY.verify_network_capacity(
+        cidr_block_str=vpc.cidr_block, resource_name=vpc.id, logger=logger
     ):
         logger.info(f"VPC {vpc.id} verification succeeded.")
         return True
     return False
 
 
-def _get_subnets_from_subnet_ids(subnet_ids: List[str], region: str) -> List[Any]:
+def _get_subnets_from_subnet_ids(
+    subnet_ids: List[str], region: str, logger: CloudSetupLogger
+) -> List[Any]:
     return [
-        _get_subnet(subnet_arn=subnet_id, region=region) for subnet_id in subnet_ids
+        _get_subnet(subnet_arn=subnet_id, region=region, logger=logger)
+        for subnet_id in subnet_ids
     ]
 
 
@@ -114,7 +138,7 @@ def verify_aws_subnets(  # noqa: PLR0911
     cloud_resource: CreateCloudResource,
     region: str,
     is_private_network: bool,
-    logger: BlockLogger,
+    logger: CloudSetupLogger,
     ignore_capacity_errors: bool = False,  # TODO: Probably don't do this forever. Its kinda hacky
     strict: bool = False,
 ) -> bool:
@@ -136,17 +160,26 @@ def verify_aws_subnets(  # noqa: PLR0911
             for subnet_id_with_az in cloud_resource.aws_subnet_ids_with_availability_zones
         ]
     else:
+        logger.log_resource_error(
+            CloudAnalyticsEventCloudResource.AWS_SUBNET,
+            CloudSetupError.MISSING_CLOUD_RESOURCE_ID,
+        )
         logger.error("Missing subnet IDs.")
         return False
 
     # We must have at least 2 subnets since services requires 2 different subnets to setup ALB.
     if len(subnet_ids) < 2:
+        logger.log_resource_error(
+            CloudAnalyticsEventCloudResource.AWS_SUBNET, CloudSetupError.ONLY_ONE_SUBNET
+        )
         logger.error(
             "Need at least 2 subnets for a cloud. This is required for Anyscale services to function properly."
         )
         return False
 
-    subnets = _get_subnets_from_subnet_ids(subnet_ids=subnet_ids, region=region)
+    subnets = _get_subnets_from_subnet_ids(
+        subnet_ids=subnet_ids, region=region, logger=logger
+    )
     subnet_azs = set()
 
     for subnet, subnet_id in zip(subnets, subnet_ids):
@@ -166,6 +199,10 @@ def verify_aws_subnets(  # noqa: PLR0911
 
         # Verify that the subnet is in the provided VPC all of these are in the same VPC.
         if subnet.vpc_id != cloud_resource.aws_vpc_id:
+            logger.log_resource_error(
+                CloudAnalyticsEventCloudResource.AWS_SUBNET,
+                CloudSetupError.SUBNET_NOT_IN_VPC,
+            )
             logger.error(
                 f"The subnet {subnet_id} is not in a vpc of this cloud. The vpc of this subnet is {subnet.vpc_id} and the vpc of this cloud is {cloud_resource.aws_vpc_id}."
             )
@@ -184,6 +221,9 @@ def verify_aws_subnets(  # noqa: PLR0911
         subnet_azs.add(subnet.availability_zone)
 
     if len(subnet_azs) < 2:
+        logger.log_resource_error(
+            CloudAnalyticsEventCloudResource.AWS_SUBNET, CloudSetupError.ONLY_ONE_AZ,
+        )
         logger.error(
             "Subnets should be in at least 2 Availability Zones. This is required for Anyscale services to function properly."
         )
@@ -196,12 +236,14 @@ def verify_aws_subnets(  # noqa: PLR0911
 
 
 def associate_aws_subnets_with_azs(
-    aws_subnet_ids: List[str], region: str
+    aws_subnet_ids: List[str], region: str, logger: CloudSetupLogger
 ) -> List[SubnetIdWithAvailabilityZoneAWS]:
     """This function combines the subnets with its availability zone.
     """
 
-    subnets = _get_subnets_from_subnet_ids(subnet_ids=aws_subnet_ids, region=region)
+    subnets = _get_subnets_from_subnet_ids(
+        subnet_ids=aws_subnet_ids, region=region, logger=logger
+    )
 
     # combine subnet and its availability zone
     subnet_ids_with_availability_zones = [
@@ -217,7 +259,7 @@ def associate_aws_subnets_with_azs(
 def _get_roles_from_cloud_resource(
     cloud_resource: CreateCloudResource,
     boto3_session: boto3.Session,
-    logger: BlockLogger,
+    logger: CloudSetupLogger,
 ) -> Optional[List[Any]]:
     iam = boto3_session.resource("iam")
     roles = [
@@ -230,6 +272,9 @@ def _get_roles_from_cloud_resource(
         try:
             role.load()
         except ClientError as e:
+            logger.log_resource_exception(
+                CloudAnalyticsEventCloudResource.AWS_IAM_ROLE, e
+            )
             if e.response["Error"]["Code"] == "NoSuchEntity":
                 logger.error(f"Could not find role: {role.name}")
                 return None
@@ -237,11 +282,11 @@ def _get_roles_from_cloud_resource(
     return roles
 
 
-def verify_aws_iam_roles(  # noqa: PLR0911
+def verify_aws_iam_roles(  # noqa: PLR0911, PLR0912
     cloud_resource: CreateCloudResource,
     boto3_session: boto3.Session,
     anyscale_aws_account: str,
-    logger: BlockLogger,
+    logger: CloudSetupLogger,
     cloud_id: str,
     strict: bool = False,
     _use_strict_iam_permissions: bool = False,
@@ -249,6 +294,10 @@ def verify_aws_iam_roles(  # noqa: PLR0911
 
     logger.info("Verifying IAM roles ...")
     if not cloud_resource.aws_iam_role_arns:
+        logger.log_resource_error(
+            CloudAnalyticsEventCloudResource.AWS_IAM_ROLE,
+            CloudSetupError.MISSING_CLOUD_RESOURCE_ID,
+        )
         logger.error("Missing IAM role arns.")
         return False
     accounts = [
@@ -256,6 +305,10 @@ def verify_aws_iam_roles(  # noqa: PLR0911
         for role in cloud_resource.aws_iam_role_arns
     ]
     if len(set(accounts)) != 1:
+        logger.log_resource_error(
+            CloudAnalyticsEventCloudResource.AWS_IAM_ROLE,
+            CloudSetupError.IAM_ROLE_ACCOUNT_MISMATCH,
+        )
         logger.error(
             f"All IAM roles must be in the same AWS account: {cloud_resource.aws_iam_role_arns}"
         )
@@ -325,6 +378,15 @@ def verify_aws_iam_roles(  # noqa: PLR0911
 
     # verifying data plane role: ray autoscaler role
     cluster_node_role = roles[1]
+    assume_role_policy_document = cluster_node_role.assume_role_policy_document
+    if not verify_data_plane_role_assume_role_policy(
+        assume_role_policy_document=assume_role_policy_document,
+    ):
+        logger.error(
+            f"Cluster Node IAM role {cluster_node_role.arn} does not contain expected assume role policy. It must give trust to AWS service EC2."
+        )
+        return False
+
     policy_names = [
         policy.policy_name for policy in cluster_node_role.attached_policies.all()
     ]
@@ -345,9 +407,13 @@ def verify_aws_iam_roles(  # noqa: PLR0911
         )
         == 0
     ):
-        logger.warning(
+        logger.log_resource_error(
+            CloudAnalyticsEventCloudResource.AWS_IAM_ROLE,
+            CloudSetupError.INSTANCE_PROFILE_NOT_FOUND,
+        )
+        logger.error(
             f"Dataplane role {cluster_node_role.arn} is required to have an instance profile with the name {cluster_node_role.name}."
-            "\nPlease create this isntance profile and associate it to the role."
+            "\nPlease create this instance profile and associate it to the role."
         )
         return False
 
@@ -358,11 +424,15 @@ def verify_aws_iam_roles(  # noqa: PLR0911
 def verify_aws_security_groups(  # noqa: PLR0912
     cloud_resource: CreateCloudResource,
     boto3_session: boto3.Session,
-    logger: BlockLogger,
+    logger: CloudSetupLogger,
     strict: bool = False,
 ) -> bool:
     logger.info("Verifying security groups ...")
     if not cloud_resource.aws_security_groups:
+        logger.log_resource_error(
+            CloudAnalyticsEventCloudResource.AWS_SECURITY_GROUP,
+            CloudSetupError.MISSING_CLOUD_RESOURCE_ID,
+        )
         logger.error("Missing security group IDs.")
         return False
 
@@ -381,6 +451,10 @@ def verify_aws_security_groups(  # noqa: PLR0912
                     "Security group", anyscale_security_group_id, logger
                 )
                 return False
+            else:
+                logger.log_resource_exception(
+                    CloudAnalyticsEventCloudResource.AWS_SECURITY_GROUP, e
+                )
             raise e
         anyscale_security_groups.append(anyscale_security_group)
 
@@ -419,6 +493,10 @@ def verify_aws_security_groups(  # noqa: PLR0912
         sg_rule.get("GroupId") in aws_security_group_ids
         for sg_rule in inbound_sg_rule_with_self
     ):
+        logger.log_resource_error(
+            CloudAnalyticsEventCloudResource.AWS_SECURITY_GROUP,
+            CloudSetupError.INTERNAL_COMMUNICATION_NOT_ALLOWED,
+        )
         logger.error(
             f"Security groups {aws_security_group_ids} do not contain inbound permission for all ports for traffic from the same security group."
         )
@@ -439,11 +517,15 @@ def verify_aws_s3(  # noqa: PLR0911, PLR0912
     cloud_resource: CreateCloudResource,
     boto3_session: boto3.Session,
     region: str,
-    logger: BlockLogger,
+    logger: CloudSetupLogger,
     strict: bool = False,
 ) -> bool:
     logger.info("Verifying S3 ...")
     if not cloud_resource.aws_s3_id:
+        logger.log_resource_error(
+            CloudAnalyticsEventCloudResource.AWS_S3_BUCKET,
+            CloudSetupError.MISSING_CLOUD_RESOURCE_ID,
+        )
         logger.error("Missing S3 ID.")
         return False
 
@@ -477,6 +559,7 @@ def verify_aws_s3(  # noqa: PLR0911, PLR0912
     try:
         cors_rules = s3_bucket.Cors().cors_rules
     except ClientError as e:
+        logger.log_resource_exception(CloudAnalyticsEventCloudResource.AWS_S3_BUCKET, e)
         if e.response["Error"]["Code"] == "NoSuchCORSConfiguration":
             logger.warning(
                 f"S3 bucket {bucket_name} does not have CORS rules. This is safe to ignore if you are not using Anyscale UI. Otherwise please create the correct CORS rule for Anyscale according to https://docs.anyscale.com/cloud-deployment/aws/manage-clouds#s3"
@@ -488,7 +571,13 @@ def verify_aws_s3(  # noqa: PLR0911, PLR0912
             raise e
 
     for rule in cors_rules:
-        assert isinstance(rule, dict), "Malformed CORS rule."
+        if not isinstance(rule, dict):
+            logger.log_resource_error(
+                CloudAnalyticsEventCloudResource.AWS_S3_BUCKET,
+                CloudSetupError.MALFORMED_CORS_RULE,
+            )
+            logger.error(f"Malformed CORS rule {rule} for your S3 bucket.")
+            return False
         has_correct_cors_rule = (
             ANYSCALE_HOST in rule.get("AllowedOrigins", [])
             and "*" in rule.get("AllowedHeaders", [])
@@ -496,6 +585,10 @@ def verify_aws_s3(  # noqa: PLR0911, PLR0912
         )
 
     if not has_correct_cors_rule:
+        logger.log_resource_error(
+            CloudAnalyticsEventCloudResource.AWS_S3_BUCKET,
+            CloudSetupError.INCORRECT_CORS_RULE,
+        )
         logger.warning(
             f"S3 bucket {bucket_name} does not have the correct CORS rule for Anyscale. This is safe to ignore if you are not using Anyscale UI. Otherwise please create the correct CORS rule for Anyscale according to https://docs.anyscale.com/anyscale-cloud-administration/deploy-on-aws#appendix-detailed-resource-requirements"
         )
@@ -538,7 +631,7 @@ def verify_aws_s3(  # noqa: PLR0911, PLR0912
 
 
 def _get_network_interfaces_from_mount_targets(
-    mount_targets_response: dict, boto3_session: Any, logger: BlockLogger
+    mount_targets_response: dict, boto3_session: Any, logger: CloudSetupLogger
 ) -> List[Any]:
     ec2 = boto3_session.resource("ec2")
     network_interfaces = []
@@ -559,11 +652,15 @@ def _get_network_interfaces_from_mount_targets(
 def verify_aws_efs(  # noqa: PLR0911, PLR0912, C901
     cloud_resource: CreateCloudResource,
     boto3_session: boto3.Session,
-    logger: BlockLogger,
+    logger: CloudSetupLogger,
     strict: bool = False,
 ) -> bool:
     logger.info("Verifying EFS ...")
     if not cloud_resource.aws_efs_id:
+        logger.log_resource_error(
+            CloudAnalyticsEventCloudResource.AWS_EFS,
+            CloudSetupError.MISSING_CLOUD_RESOURCE_ID,
+        )
         logger.error("Missing EFS ID.")
         return False
     subnet_ids = []
@@ -591,6 +688,8 @@ def verify_aws_efs(  # noqa: PLR0911, PLR0912, C901
         if e.response["Error"]["Code"] == "FileSystemNotFound":
             log_resource_not_found_error("EFS", cloud_resource.aws_efs_id, logger)
             return False
+        else:
+            logger.log_resource_exception(CloudAnalyticsEventCloudResource.AWS_EFS, e)
         raise e
 
     if len(file_systems_response.get("FileSystems", [])) == 0:
@@ -603,7 +702,11 @@ def verify_aws_efs(  # noqa: PLR0911, PLR0912, C901
     )
     mount_targets = mount_targets_response.get("MountTargets")
     if not mount_targets:
-        logger.warning(
+        logger.log_resource_error(
+            CloudAnalyticsEventCloudResource.AWS_EFS,
+            CloudSetupError.MOUNT_TARGET_NOT_FOUND,
+        )
+        logger.error(
             f"EFS with id {cloud_resource.aws_efs_id} does not contain mount targets."
         )
         return False
@@ -613,9 +716,19 @@ def verify_aws_efs(  # noqa: PLR0911, PLR0912, C901
     if cloud_resource.aws_efs_mount_target_ip and (
         cloud_resource.aws_efs_mount_target_ip not in mount_target_ips
     ):
+        logger.log_resource_error(
+            CloudAnalyticsEventCloudResource.AWS_EFS,
+            CloudSetupError.INVALID_MOUNT_TARGET,
+        )
         logger.error(
             f"Mount target registered with the cloud no longer exists. EFS ID: {cloud_resource.aws_efs_id} IP address: {cloud_resource.aws_efs_mount_target_ip}. Please make sure you have the correct AWS credentials set. If the EFS mount target has been deleted, please recreate the cloud or contact Anyscale for support."
         )
+        logger.error(
+            f"Valid mount target IPs for EFS ID {cloud_resource.aws_efs_id} are {mount_target_ips}. "
+            "If this happens during cloud edit, ensure that: "
+            "1) If only editing aws_efs_mount_target_ip, it belongs to the existing EFS ID. "
+            "2) If editing both efs_id and efs_mount_target_ip, the new IP is a valid target for the new efs_id."
+        )
         return False
 
     network_interfaces = _get_network_interfaces_from_mount_targets(
@@ -623,23 +736,43 @@ def verify_aws_efs(  # noqa: PLR0911, PLR0912, C901
     )
 
     expected_security_group_id = cloud_resource.aws_security_groups[0]
+
+    # Condition 1: No matching network interface in EFS mount targets for a subnet.
+    # - 1.1: EFS has mount targets in other subnets.
+    #        Subnet communicates with EFS through cross AZ, incurring cross AZ costs. (warning)
+    # - 1.2: EFS doesn't have mount target, the subnet cannot communicate with EFS. (error)
+    #   (note) A previous check ensures EFS has mount targets if this point is reached.
+    # --------------------------------------------------------------------------------------------------------------
+    # Condition 2: Subnet has a matching network interface in EFS mount targets.
+    # - 2.1: Network interface has a registered security group. (happy path)
+    # - 2.2: Network interface lacks a registered security group but has another security group.
+    #   If configured correctly, subnet can still communicate with EFS. (warning)
+    # --------------------------------------------------------------------------------------------------------------
     for subnet_id in subnet_ids:
-        contains_subnet_id_security_group = False
+        contains_subnet_id = False
+        contains_registered_security_group = False
         for network_interface in network_interfaces:
             network_interface_security_group_ids = [
                 group["GroupId"]
                 for group in network_interface.groups
                 if group.get("GroupId")
             ]
-            if (
-                network_interface.subnet_id == subnet_id
-                and expected_security_group_id in network_interface_security_group_ids
-            ):
-                contains_subnet_id_security_group = True
-                break
-        if not contains_subnet_id_security_group:
+            if network_interface.subnet_id == subnet_id:
+                contains_subnet_id = True
+                if expected_security_group_id in network_interface_security_group_ids:
+                    contains_registered_security_group = True
+                    break
+        if not contains_subnet_id:
+            # condition 1.1.
             logger.warning(
-                f"EFS with id {cloud_resource.aws_efs_id} does not contain network interface with subnet id {subnet_id} and security group id {cloud_resource.aws_security_groups[0]}."
+                f"EFS with id {cloud_resource.aws_efs_id} does not contain a mount target with the subnet {subnet_id}, which might introduce cross AZ networking cost."
+            )
+            if strict:
+                return False
+        elif not contains_registered_security_group:
+            # condition 2.2.
+            logger.warning(
+                f"EFS with id {cloud_resource.aws_efs_id} does not contain a mount target with the subnet {subnet_id} and security group id {cloud_resource.aws_security_groups[0]}. This misconfiguration might pose security risks and incur connection issues, preventing the EFS from working as expected."
             )
             if strict:
                 return False
@@ -671,11 +804,15 @@ def verify_aws_efs(  # noqa: PLR0911, PLR0912, C901
 def verify_aws_cloudformation_stack(
     cloud_resource: CreateCloudResource,
     boto3_session: boto3.Session,
-    logger: BlockLogger,
+    logger: CloudSetupLogger,
     strict: bool = False,  # strict is currently unused # noqa: ARG001
 ) -> bool:
     logger.info("Verifying CloudFormation stack ...")
     if not cloud_resource.aws_cloudformation_stack_id:
+        logger.log_resource_error(
+            CloudAnalyticsEventCloudResource.AWS_CLOUDFORMATION,
+            CloudSetupError.MISSING_CLOUD_RESOURCE_ID,
+        )
         logger.error("Missing CloudFormation stack id.")
         return False
 
@@ -691,6 +828,10 @@ def verify_aws_cloudformation_stack(
                 logger,
             )
             return False
+        else:
+            logger.log_resource_exception(
+                CloudAnalyticsEventCloudResource.AWS_CLOUDFORMATION, e
+            )
         raise e
 
     logger.info(
