@@ -121,6 +121,12 @@ def cloud_set_default(
     hidden=True,
     help="Whether to use the legacy stack.",
 )
+@click.option(
+    "--enable-head-node-fault-tolerance",
+    is_flag=True,
+    default=False,
+    help="Whether to enable head node fault tolerance for services.",
+)
 def setup_cloud(  # noqa: PLR0913
     provider: str,
     region: str,
@@ -129,6 +135,7 @@ def setup_cloud(  # noqa: PLR0913
     functional_verify: Optional[str],
     anyscale_managed: bool,  # noqa: ARG001
     use_legacy_stack: bool,
+    enable_head_node_fault_tolerance: bool,
 ) -> None:
     # TODO (congding): remove `anyscale_managed` in the future, now keeping it for compatibility
     cluster_management_stack_version = (
@@ -143,6 +150,7 @@ def setup_cloud(  # noqa: PLR0913
             name=name,
             functional_verify=functional_verify,
             cluster_management_stack_version=cluster_management_stack_version,
+            enable_head_node_fault_tolerance=enable_head_node_fault_tolerance,
         )
     elif provider == "gcp":
         if not project_id:
@@ -154,6 +162,7 @@ def setup_cloud(  # noqa: PLR0913
             project_id=project_id,
             functional_verify=functional_verify,
             cluster_management_stack_version=cluster_management_stack_version,
+            enable_head_node_fault_tolerance=enable_head_node_fault_tolerance,
         )
 
 
@@ -535,3 +544,98 @@ def cloud_verify(
         functional_verify=functional_verify,
         strict=strict,
     )
+
+
+@cloud_cli.command(name="edit", help="Edit anyscale cloud resource.")
+@click.argument("cloud-name", required=False)
+@click.option("--name", "-n", help="Edit cloud by name.", type=str)
+@click.option(
+    "--cloud-id",
+    "--id",
+    help="Edit cloud by id, alternative to cloud name.",
+    required=False,
+)
+@click.option(
+    "--aws-s3-id", help="New S3 bucket ID.", required=False, type=str,
+)
+@click.option("--aws-efs-id", help="New EFS ID.", required=False, type=str)
+@click.option(
+    "--aws-efs-mount-target-ip",
+    help="New EFS mount target IP.",
+    required=False,
+    type=str,
+)
+@click.option(
+    "--gcp-filestore-instance-id",
+    help="New GCP filestore instance id.",
+    required=False,
+    type=str,
+)
+@click.option(
+    "--gcp-filestore-location",
+    help="New GCP filestore location.",
+    required=False,
+    type=str,
+)
+@click.option(
+    "--gcp-cloud-storage-bucket-name",
+    help="New GCP Cloud storage bucket name.",
+    required=False,
+    type=str,
+)
+@click.option(
+    "--functional-verify",
+    help="Verify the cloud is functional. This will check that the cloud can launch workspace/service.",
+    required=False,
+    is_flag=False,
+    flag_value="workspace",
+)
+def cloud_edit(  # noqa: PLR0913
+    cloud_name: Optional[str],
+    name: Optional[str],
+    cloud_id: Optional[str],
+    aws_s3_id: Optional[str],
+    aws_efs_id: Optional[str],
+    aws_efs_mount_target_ip: Optional[str],
+    gcp_filestore_instance_id: Optional[str],
+    gcp_filestore_location: Optional[str],
+    gcp_cloud_storage_bucket_name: Optional[str],
+    functional_verify: Optional[str],
+) -> None:
+    if cloud_name and name and cloud_name != name:
+        raise click.ClickException(
+            "The positional argument CLOUD_NAME and the keyword argument --name "
+            "were both provided. Please only provide one of these two arguments."
+        )
+    if any(
+        [
+            aws_s3_id,
+            aws_efs_id,
+            aws_efs_mount_target_ip,
+            gcp_filestore_instance_id,
+            gcp_filestore_location,
+            gcp_cloud_storage_bucket_name,
+        ]
+    ):
+        if any([gcp_filestore_instance_id, gcp_filestore_location]) and not all(
+            [gcp_filestore_instance_id, gcp_filestore_location]
+        ):
+            # Make sure both gcp_filestore_instance_id and gcp_filestore_location are provided if you want to edit filestore.
+            raise click.ClickException(
+                "Please provide both --gcp-filestore-instance-id and --gcp-filestore-location if you want to edit filestore."
+            )
+        CloudController().edit_cloud(
+            cloud_name=cloud_name or name,
+            cloud_id=cloud_id,
+            aws_s3_id=aws_s3_id,
+            aws_efs_id=aws_efs_id,
+            aws_efs_mount_target_ip=aws_efs_mount_target_ip,
+            gcp_filestore_instance_id=gcp_filestore_instance_id,
+            gcp_filestore_location=gcp_filestore_location,
+            gcp_cloud_storage_bucket_name=gcp_cloud_storage_bucket_name,
+            functional_verify=functional_verify,
+        )
+    else:
+        raise click.ClickException(
+            "Please provide at least one of the following arguments: --aws-s3-id, --aws-efs-id, --aws-efs-mount-target-ip, --gcp-filestore-instance-id, --gcp-filestore-location, --gcp-cloud-storage-bucket-name."
+        )
