@@ -446,3 +446,17 @@ def list(  # noqa: A001, PLR0913
         cloud_id=cloud_id,
         cloud_name=cloud,
     )
+
+
+@cluster_cli.command(
+    name="network_debug",
+    help="Debug local network connectivity to a cluster.",
+    hidden=True,
+)
+@click.argument(
+    "cluster_id", required=True, default=None,
+)
+def network_debug(cluster_id: Optional[str],) -> None:
+    """Debug network connectivity to a given Anyscale cluster."""
+    cluster_controller = ClusterController()
+    cluster_controller.debug_networking(cluster_id=cluster_id)
