@@ -1,6 +1,7 @@
 from datetime import datetime
 import os
 from typing import Any, Dict, Optional, Tuple
+from urllib.parse import urlparse
 
 import click
 import tabulate
@@ -31,6 +32,7 @@ from anyscale.sdk.anyscale_client import (
     ClusterEnvironmentBuild,
     ComputeTemplate,
     CreateCluster,
+    SessionState,
     StartClusterOptions,
     UpdateCluster,
 )
@@ -48,6 +50,7 @@ from anyscale.util import (
     PROJECT_NAME_ENV_VAR,
     wait_for_session_start,
 )
+from anyscale.utils.cluster_debug import debug_cluster
 
 
 class ClusterController(BaseController):
@@ -428,6 +431,34 @@ class ClusterController(BaseController):
         )
         print(f"Clusters:\n{table}")
 
+    def debug_networking(self, cluster_id: Optional[str],) -> bool:
+        cluster = self.anyscale_api_client.get_cluster(cluster_id).result
+        if cluster.state != SessionState.RUNNING:
+            raise click.ClickException(
+                f"Cluster {cluster_id} is not running. Cannot debug networking"
+            )
+
+        # TODO(ilr) modify messaging based on whether or not the cloud of this cluster uses Private IPs
+        url = cluster.head_node_info.url
+        self.log.info(
+            f"Beginning network diagnostics for cluster {cluster_id} at {url}"
+        )
+
+        success = True
+        for test_result in debug_cluster(
+            self.log, urlparse(url).netloc, cluster.head_node_info.ip_address
+        ):
+            if test_result.success:
+                self.log.info(f"{test_result.name}: ✅")
+                if test_result.warnings:
+                    self.log.warning(test_result.warnings)
+            else:
+                self.log.error(
+                    f"{test_result.name}: ❌ Error Message: {test_result.error}"
+                )
+                success = False
+        return success
+
     # Helpers
 
     def _validate_args_to_find_cluster(
