@@ -8,7 +8,7 @@ import random
 import string
 import time
 import traceback
-from typing import Any, Callable, cast, Dict, List, Optional, Tuple, Type, Union
+from typing import Any, Callable, cast, Dict, List, Optional, Tuple, Union
 
 import click
 from pydantic import BaseModel
@@ -20,20 +20,18 @@ import yaml
 
 from anyscale.api_utils.exceptions.log_retrieval_errors import (
     ExpectedLogRetrievalError,
-    UnsupportedLogRetrievalMethodError,
     wrap_as_unsupported_log_retrieval_method_error,
     wrap_job_run_log_not_retrievable_on_active_cluster_error,
 )
 from anyscale.api_utils.job_logs_util import (
     _get_job_logs_from_storage_bucket,
+    _get_job_logs_from_storage_bucket_streaming,
     _get_logs_from_active_job_run,
 )
-from anyscale.api_utils.job_util import _is_production_job_on_v2_cloud
 from anyscale.api_utils.logs_util import _stream_log_from_ray_websocket
 from anyscale.cli_logger import LogsLogger
 from anyscale.client.openapi_client import (
     ComputeTemplate,
-    JobsLogsQueryInfo,
     ProductionJob,
     ProductionJobConfig,
 )
@@ -183,6 +181,7 @@ class JobController(BaseController):
         super().__init__(initialize_auth_api_client, raise_structured_exception)
         self.log = log
         self.log.open_block("Output")
+        self._cluster_journal_events_start_line = 0
 
     def submit(
         self,
@@ -333,7 +332,6 @@ class JobController(BaseController):
         self,
         job_name: Optional[str] = None,
         job_id: Optional[str] = None,
-        is_service: bool = False,
         target_state: str = HaJobStates.SUCCESS,
         interval_secs: float = 10.0,
         timeout_secs=None,
@@ -343,12 +341,7 @@ class JobController(BaseController):
                 f"`{target_state}` is not a valid Job state. Allowed states are {HaJobStates.allowable_values}"
             )
         job_id_or_name = job_name or job_id
-        job_id = cast(
-            str,
-            self._resolve_job_object(
-                job_id, job_name, entity_type="service" if is_service else "job"
-            ).id,
-        )
+        job_id = cast(str, self._resolve_job_object(job_id, job_name).id,)
         with self.log.spinner(f"Waiting for Job `{job_id_or_name}`...") as spinner:
             state = None
             for _ in poll(interval_secs=interval_secs, timeout_secs=timeout_secs):
@@ -384,33 +377,24 @@ class JobController(BaseController):
         project_id: Optional[str],
         include_archived: bool,
         max_items: int,
-        is_service: bool = False,
     ) -> None:
         """
-        This function will either list jobs or services based on the value of `is_service`.
-        Both functionalities are combined in one function because the API to list both these
-        entities is currently the same.
+        This function will list jobs.
         """
-        entity_type = "services" if is_service else "jobs"
-        print(f'View your {entity_type} in the UI at {get_endpoint(f"/{entity_type}")}')
+        print(f'View your Jobs in the UI at {get_endpoint("/jobs")}')
 
         jobs_list = []
         if job_id:
             job = self.api_client.get_job_api_v2_decorated_ha_jobs_production_job_id_get(
                 job_id
             ).result
-            if not is_service and job.is_service:
+            if job.is_service:
                 # `job_id` belongs to a service, but this function should list jobs.
                 raise click.ClickException(
                     f"ID {job_id} belongs to a Anyscale service. Please get information about "
                     f"this service with `anyscale service list --service-id {job_id}`."
                 )
-            elif is_service and not job.is_service:
-                # `job_id` belongs to a job, but this function should list services.
-                raise click.ClickException(
-                    f"ID {job_id} belongs to a Anyscale job. Please get information about "
-                    f"this job with `anyscale job list --job-id {job_id}`."
-                )
+
             output_map = {
                 "Name": job.name,
                 "Id": job.id,
@@ -425,11 +409,6 @@ class JobController(BaseController):
                 if len(job.config.entrypoint) < 100
                 else job.config.entrypoint[:100] + " ...",
             }
-            if is_service:
-                output_map["Access"] = job.access
-                output_map["URL"] = job.url
-                output_map["Token"] = job.token
-
             output_str = "\n".join(
                 [f"\t{key}: {output_map[key]}" for key in output_map]
             )
@@ -446,7 +425,7 @@ class JobController(BaseController):
                 project_id=project_id,
                 name=name,
                 creator_id=creator_id,
-                type_filter="SERVICE" if is_service else "BATCH_JOB",
+                type_filter="BATCH_JOB",
                 archive_status="ALL" if include_archived else "NOT_ARCHIVED",
                 count=10,
             )
@@ -458,7 +437,7 @@ class JobController(BaseController):
                     project_id=project_id,
                     name=name,
                     creator_id=creator_id,
-                    type_filter="SERVICE" if is_service else "BATCH_JOB",
+                    type_filter="BATCH_JOB",
                     archive_status="ALL" if include_archived else "NOT_ARCHIVED",
                     count=10,
                     paging_token=paging_token,
@@ -500,57 +479,41 @@ class JobController(BaseController):
             ],
             tablefmt="plain",
         )
-        print(f"{entity_type.capitalize()}:\n{table}")
+        print(f"JOBS:\n{table}")
 
-    def archive(
-        self, job_id: Optional[str], job_name: Optional[str], is_service: bool = False,
-    ) -> None:
+    def archive(self, job_id: Optional[str], job_name: Optional[str]) -> None:
         """
-        This function will either archive jobs or services based on the value of `is_service`.
-        Both functionalities are combined in one function because the API to archive both these
-        entities is currently the same.
+        This function will archive jobs.
         """
-        entity_type = "service" if is_service else "job"
-        job_resp: DecoratedProductionJob = self._resolve_job_object(
-            job_id, job_name, entity_type
-        )
+        job_resp: DecoratedProductionJob = self._resolve_job_object(job_id, job_name)
         self.api_client.archive_job_api_v2_decorated_ha_jobs_production_job_id_archive_post(
             job_resp.id
         )
-        self.log.info(
-            f"{entity_type.capitalize()} {job_resp.id} is successfully archived."
-        )
+        self.log.info(f"Job {job_resp.id} is successfully archived.")
 
-    def terminate(
-        self, job_id: Optional[str], job_name: Optional[str], is_service: bool = False,
-    ) -> None:
+    def terminate(self, job_id: Optional[str], job_name: Optional[str]) -> None:
         """
-        This function will either terminate jobs or services based on the value of `is_service`.
-        Both functionalities are combined in one function because the API to terminate both these
-        entities is currently the same.
+        This function will terminate jobs.
         """
-        entity_type = "service" if is_service else "job"
-        job_resp: DecoratedProductionJob = self._resolve_job_object(
-            job_id, job_name, entity_type
-        )
+        job_resp: DecoratedProductionJob = self._resolve_job_object(job_id, job_name)
         job = self.api_client.terminate_job_api_v2_decorated_ha_jobs_production_job_id_terminate_post(
             job_resp.id
         ).result
-        self.log.info(f"{entity_type.capitalize()} {job.id} has begun terminating...")
+        self.log.info(f"Job {job.id} has begun terminating...")
         self.log.info(
-            f" Current state of {entity_type}: {job.state.current_state}. Goal state of {entity_type}: {job.state.goal_state}"
+            f" Current state of Job: {job.state.current_state}. Goal state of Job: {job.state.goal_state}"
         )
         self.log.info(
-            f"Query the status of the {entity_type} with `anyscale {entity_type} list --{entity_type}-id {job.id}`."
+            f"Query the status of the Job with `anyscale job list --job-id {job.id}`."
         )
 
     def _resolve_job_object(
-        self, job_id: Optional[str], job_name: Optional[str], entity_type: str = "job"
+        self, job_id: Optional[str], job_name: Optional[str]
     ) -> DecoratedProductionJob:
         """Given job_id or job_name, retrieve decorated ha job spec"""
         if job_id is None and job_name is None:
             raise click.ClickException(
-                f"Either `--id` or `--name` must be passed in for {entity_type}."
+                "Either `--id` or `--name` must be passed in for Job."
             )
         if job_id:
             return self._get_job(job_id)
@@ -558,17 +521,16 @@ class JobController(BaseController):
         jobs_list_resp: List[
             DecoratedProductionJob
         ] = self.api_client.list_decorated_jobs_api_v2_decorated_ha_jobs_get(
-            name=job_name,
-            type_filter="BATCH_JOB" if entity_type == "job" else "SERVICE",
+            name=job_name, type_filter="BATCH_JOB",
         ).results
         if len(jobs_list_resp) == 0:
             raise click.ClickException(
-                f"No {entity_type} found with name {job_name}. Please either pass `--id` or list the "
-                f"available {entity_type}s with `anyscale {entity_type} list`."
+                f"No Job found with name {job_name}. Please either pass `--id` or list the "
+                f"available Jobs with `anyscale job list`."
             )
         if len(jobs_list_resp) > 1:
             raise click.ClickException(
-                f"Multiple {entity_type}s found with name {job_name}. Please specify the `--id` instead."
+                f"Multiple Jobs found with name {job_name}. Please specify the `--id` instead."
             )
         return jobs_list_resp[0]
 
@@ -600,6 +562,7 @@ class JobController(BaseController):
         (encountered when initially submitting).
 
         Returns the job."""
+        start = time.monotonic()
         job = self._resolve_job_object(job_id, job_name)
         last_job_run_id: str = job.last_job_run_id
         job_state = job.state.current_state
@@ -609,25 +572,35 @@ class JobController(BaseController):
                     raise click.ClickException(
                         f"Can't find latest job run for {job_state} job."
                     )
-                spinner.text = f"Waiting for a job run, current state is {job_state}..."
-                time.sleep(5)
+                if self._cluster_journal_events_start_line == 0:
+                    spinner.text = (
+                        f"Waiting for a job run, current state is {job_state}..."
+                    )
+                time.sleep(max(0, 3 - (time.monotonic() - start)))
+                start = time.monotonic()
                 job = self._get_job(job.id)
                 last_job_run_id = job.last_job_run_id
+                if job.state.cluster_id:
+                    # Once we have a cluster id, we start printing the cluster journal event logs with each loop.
+                    cluster_journal_events = self._api_client.get_startup_logs_api_v2_sessions_session_id_startup_logs_get(
+                        job.state.cluster_id,
+                        start_line=self._cluster_journal_events_start_line,
+                        end_line=10000000,
+                    ).result
+                    lines = cluster_journal_events.lines.splitlines()
+                    if len(lines):
+                        spinner.succeed("Job run found. Cluster launching...")
+                    self._cluster_journal_events_start_line = (
+                        cluster_journal_events.start_line
+                        + cluster_journal_events.num_lines
+                    )
+
+                    for line in lines:
+                        self.log.info(line)
+
                 job_state = job.state.current_state
         return job
 
-    def _wait_for_job_running(self, job_id: str) -> None:
-        with self.log.spinner("Waiting for job to retry...") as spinner:
-            for _ in poll():
-                job_object = self._get_job(job_id)
-                job_state = job_object.state.current_state
-                if job_state in _PENDING_STATES:
-                    spinner.text = (
-                        f"Waiting for job to retry, current state is {job_state}..."
-                    )
-                else:
-                    return
-
     def _print_logs_for_active_job_run(
         self, job_run_id: str, should_follow: bool
     ) -> None:
@@ -689,6 +662,75 @@ class JobController(BaseController):
         for line in logs.splitlines():
             self.log.log(line)
 
+    def _print_logs_using_streaming_job_logs(
+        self, job_run_id: str, follow: bool = False
+    ) -> None:
+        """Retrieves logs from the streaming job logs folder in S3/GCS"""
+        logs = ""
+        next_page_token = None
+        # Keep track of if any logs have been printed yet,
+        # If not, we assume the cluster recently launched and we
+        # give more leeway for the logs to be available.
+        have_jobs_started_producing_logs = False
+        with self.log.spinner("Retrieving logs..."):
+            (
+                logs,
+                next_page_token,
+                cluster_journal_events_start_line,
+                job_finished,
+            ) = asyncio.run(
+                _get_job_logs_from_storage_bucket_streaming(
+                    self._api_client,
+                    self.log,
+                    job_run_id=job_run_id,
+                    remove_escape_chars=False,
+                    next_page_token=next_page_token,
+                    cluster_journal_events_start_line=self._cluster_journal_events_start_line,
+                )
+            )
+
+        if len(logs):
+            have_jobs_started_producing_logs = True
+
+        for line in logs.splitlines():
+            self.log.log(line)
+
+        # Continuously poll for logs.
+        terminal_state_count = 0
+        while follow:
+            start = time.monotonic()
+            if job_finished:
+                # Let's wait before terminating the loop to give the logs a chance to catch up.
+                terminal_state_count += 1
+                # Once jobs produce logs, we know we do not have to wait as long for those logs
+                # to be uploaded to S3 since the cluster is already running.
+                max_iterations = 4 if have_jobs_started_producing_logs else 6
+                if terminal_state_count >= max_iterations:
+                    self.log.info("Job run reached terminal state.")
+                    return
+
+            (
+                logs,
+                next_page_token,
+                cluster_journal_events_start_line,
+                job_finished,
+            ) = asyncio.run(
+                _get_job_logs_from_storage_bucket_streaming(
+                    self._api_client,
+                    self.log,
+                    job_run_id=job_run_id,
+                    remove_escape_chars=False,
+                    next_page_token=next_page_token,
+                    cluster_journal_events_start_line=cluster_journal_events_start_line,
+                )
+            )
+
+            for line in logs.splitlines():
+                self.log.log(line)
+
+            # Wait at least 5 seconds between iterations.
+            time.sleep(max(0, 5 - (time.monotonic() - start)))
+
     def logs(
         self,
         job_id: Optional[str] = None,
@@ -705,6 +747,9 @@ class JobController(BaseController):
         """
         # This logic will be simplified once the migration to Anyscale V2 is complete.
         job = self._wait_for_a_job_run(job_id, job_name)
+        is_streaming_job_logs_on = self._api_client.check_is_feature_flag_on_api_v2_userinfo_check_is_feature_flag_on_get(
+            "ray-job-log-streaming"
+        ).result.is_on
         last_job_run_id: str = job.last_job_run_id
         job_state: HaJobStates = job.state.current_state
         job_run_ids: List[str] = (
@@ -716,122 +761,41 @@ class JobController(BaseController):
             self.log.open_block(
                 job_run_id, f"Job Run Id: {job_run_id}", auto_close=True,
             )
-            # 1. Last job run, and 2. job is RUNNING implies (==) job run is RUNNING
-            is_last_job_run_and_active = (
-                job_run_id == last_job_run_id and job_state == HaJobStates.RUNNING
-            )
-            get_logs_fns: List[Callable[[], None]] = [
-                *(
-                    # If the job run is RUNNING, retrieve logs from the active cluster
-                    []
-                    if not is_last_job_run_and_active
-                    else [
-                        lambda: self._print_logs_for_active_job_run(
-                            job_run_id, should_follow  # noqa: B023
-                        )
-                    ]
-                ),
-                # Else (job run is done) or if the previous retrieval method failed,
-                # retrieve logs from Anyscale's cache
-                lambda: self._print_logs_legacy(job, should_follow),  # noqa: B023
-                # Else (job run not in v1 cloud, logs expired from cache) or if the previous retrieval method failed,
-                # retrieve logs from Anyscale's cache
-                lambda: self._print_logs_for_inactive_job_run(job_run_id),  # noqa: B023
-            ]
-            for fn in get_logs_fns:
-                with contextlib.suppress(ExpectedLogRetrievalError):
-                    fn()
-                    # If `fn` didn't raise `ExpectedLogRetrievalError`, we assume logs were successfully printed.
-                    # In this case, break out of this loop and log for the next `job_run_id`
-                    break
-
-    def _print_logs_legacy(
-        self,
-        job: DecoratedProductionJob,
-        should_follow: bool = False,
-        log_provider_cls: Type[LogProvider] = LokiLogProvider,
-    ) -> None:
-        """Retrieves logs from Anyscale's backend cache. Not supported for Anyscale v2 clouds."""
-        job_id: str = job.id
-        if _is_production_job_on_v2_cloud(self.anyscale_api_client, job_id):
-            raise UnsupportedLogRetrievalMethodError(
-                "Logs are not stored Anyscale-side on clouds set up with Anyscale v2."
-            )
-
-        start_timestamp_ns = 0
-        max_iter = 1 if not should_follow else None
-        log_provider_map: Dict[str, LogProvider] = {}
-
-        num_times_logged = 0
-        for _ in poll(1, max_iter=max_iter):
-            # Fetch the latest job run
-            jr = self._get_formatted_latest_job_run(job)
-
-            # This shouldn't happen because we are waiting for it above
-            assert jr, "Could not find the latest job run"
-
-            log_provider = log_provider_map.get(jr.last_job_run_id)
-            if not log_provider:
-                # Open a new CLI block
-                # This is to ensure the logs for each job are nicely formatted
-
-                # We have not seen this job run id before. We need to construct a new log provider
-                log_info: JobsLogsQueryInfo = self.api_client.get_job_logs_query_info_api_v2_decorated_ha_jobs_production_job_id_logs_query_get(
-                    production_job_id=job_id
-                ).result
-
-                log_provider = log_provider_cls(
-                    dns_name=log_info.loki_dns_name,
-                    anyscale_token=log_info.access_token,
-                    query=log_info.loki_query,
+            if is_streaming_job_logs_on:
+                # New path for retrieving logs. Works regardless if cluster is running or dead.
+                self._print_logs_using_streaming_job_logs(
+                    job_run_id, follow=should_follow and job_run_id == last_job_run_id
+                )
+            else:
+                # 1. Last job run, and 2. job is RUNNING implies (==) job run is RUNNING
+                is_last_job_run_and_active = (
+                    job_run_id == last_job_run_id and job_state == HaJobStates.RUNNING
                 )
 
-                # Add to the cache
-                log_provider_map[jr.last_job_run_id] = log_provider
-
-            # Make sure we only have 1 open request session at a time
-            with log_provider:
-                # Flush all logs in the loki endpoint
-                last_received_logs_iteration = 0
-                for iteration in poll(interval_secs=1):
-                    # Fetch logs in the time range
-                    end_timestamp_ns = int(time.time() * 1e9)
-                    lines = log_provider.query(start_timestamp_ns, end_timestamp_ns)
-
-                    # Print the results
-                    for time_stamp, line in lines:
-                        # Update the start timestamp in case we are following or paginated.
-                        start_timestamp_ns = time_stamp + 1
-                        self.log.log(line)
-                        num_times_logged += 1
-                    if len(lines) > 0:
-                        # Record the last iteration at which we received logs
-                        last_received_logs_iteration = iteration
-
-                    # If we are following, threshold is 30 iterations (or 30 seconds)
-                    threshold = 30 if should_follow else 0
-                    if iteration - last_received_logs_iteration > threshold:
-                        # If we haven't received logs after threshold iterations, assume existing logs have been flushed
+                get_logs_fns: List[Callable[[], None]] = [
+                    *(
+                        # If the job run is RUNNING, retrieve logs from the active cluster
+                        []
+                        if not is_last_job_run_and_active
+                        else [
+                            lambda: self._print_logs_for_active_job_run(
+                                job_run_id, should_follow  # noqa: B023
+                            )
+                        ]
+                    ),
+                    # If the previous retrieval method failed or the job is not running
+                    # retrieve logs from Anyscale's cache
+                    lambda: self._print_logs_for_inactive_job_run(
+                        job_run_id  # noqa: B023
+                    ),
+                ]
+                for fn in get_logs_fns:
+                    with contextlib.suppress(ExpectedLogRetrievalError):
+                        fn()
+                        # If `fn` didn't raise `ExpectedLogRetrievalError`, we assume logs were successfully printed.
+                        # In this case, break out of this loop and log for the next `job_run_id`
                         break
 
-                # We have already flushed existing logs for this job run
-                # If the job is in a terminal state, exit
-                if jr.job_state in _TERMINAL_STATES:
-                    # If the state is terminal, exit
-                    if num_times_logged == 0:
-                        raise ExpectedLogRetrievalError(
-                            "Logs have expired from Anyscale's backend cache layer."
-                        )
-                    self.log.info(f"Job entered terminal state {jr.job_state}.")
-                    if jr.error:
-                        self.log.error(f"Job exited with error: {jr.error}")
-                    return
-
-                # If the job is in a pending state, wait for it to start running
-                # before fetching more logs
-                if jr.job_state in _PENDING_STATES:
-                    self._wait_for_job_running(job_id)
-
     def retrieve_output(
         self, job_name: Optional[str] = None, job_id: Optional[str] = None,
     ) -> None:
