@@ -10,15 +10,11 @@ from anyscale.client.openapi_client import ComputeTemplate, ProductionJob
 from anyscale.client.openapi_client.models.decorated_list_service_api_model import (
     DecoratedListServiceAPIModel,
 )
-from anyscale.client.openapi_client.models.decorated_production_job import (
-    DecoratedProductionJob,
-)
 from anyscale.client.openapi_client.models.decorated_production_service_v2_api_model import (
     DecoratedProductionServiceV2APIModel,
 )
 from anyscale.client.openapi_client.models.ha_job_states import HaJobStates
 from anyscale.controllers.base_controller import BaseController
-from anyscale.controllers.job_controller import JobController
 from anyscale.formatters.service_formatter import format_service_config_v2
 from anyscale.models.service_model import ServiceConfig
 from anyscale.project import infer_project_id
@@ -36,10 +32,6 @@ _POLL_SERVICE_VERSION_INFO_INTERVAL_IN_SECS = 3.0
 _POLL_SERVICE_VERSION_INFO_TIMEOUT_IN_SECS = 60.0 * 3
 
 
-def _is_v2_service_id(service_id: str) -> bool:
-    return service_id.startswith("service2")
-
-
 class ServiceController(BaseController):
     def __init__(
         self, log: Optional[BlockLogger] = None, initialize_auth_api_client: bool = True
@@ -49,9 +41,6 @@ class ServiceController(BaseController):
 
         super().__init__(initialize_auth_api_client=initialize_auth_api_client)
         self.log = log
-        self.job_controller = JobController(
-            initialize_auth_api_client=initialize_auth_api_client
-        )
 
     def _get_services_by_name(
         self,
@@ -373,33 +362,13 @@ class ServiceController(BaseController):
         created_by_me: bool = False,
         max_items: int = 10,
     ) -> None:
-        try:
-            self._list_via_service_list_endpoint(
-                name=name,
-                service_id=service_id,
-                project_id=project_id,
-                created_by_me=created_by_me,
-                max_items=max_items,
-            )
-        except Exception as e:  # noqa: BLE001
-            if "Services v2 is not enabled for your organization." in str(e):
-                # An exception will be thrown if the "services_v2_enable_all_features" flag is not enabled
-                # Therefore, we default to showing only Service v1.
-                # TODO: shawnp. Remove the exception logic once we enable service v2 flag for all customers
-                self.job_controller.list(
-                    name=name,
-                    job_id=service_id,
-                    project_id=project_id,
-                    include_all_users=not created_by_me,
-                    include_archived=False,
-                    max_items=max_items,
-                    is_service=True,
-                )
-            else:
-                self.log.info(
-                    "We are unable to get a list of Services."
-                    "This is unexpected and please contact Anyscale support for more info."
-                )
+        self._list_via_service_list_endpoint(
+            name=name,
+            service_id=service_id,
+            project_id=project_id,
+            created_by_me=created_by_me,
+            max_items=max_items,
+        )
 
     def _list_via_service_list_endpoint(
         self,
@@ -412,33 +381,20 @@ class ServiceController(BaseController):
     ):
         services = []
         if service_id:
-            if _is_v2_service_id(service_id):
-                service_v2_result: DecoratedProductionServiceV2APIModel = (
-                    self.api_client.get_service_api_v2_services_v2_service_id_get(
-                        service_id
-                    ).result
-                )
-                services.append(
-                    [
-                        service_v2_result.name,
-                        service_v2_result.id,
-                        service_v2_result.current_state,
-                        # TODO: change to email once https://github.com/anyscale/product/pull/18189 is merged
-                        service_v2_result.creator_id,
-                    ]
-                )
-            else:
-                service_v1_result: DecoratedProductionJob = self.api_client.get_job_api_v2_decorated_ha_jobs_production_job_id_get(
+            service_v2_result: DecoratedProductionServiceV2APIModel = (
+                self.api_client.get_service_api_v2_services_v2_service_id_get(
                     service_id
                 ).result
-                services.append(
-                    [
-                        service_v1_result.name,
-                        service_v1_result.id,
-                        service_v1_result.state.current_state,
-                        service_v1_result.creator.email,
-                    ]
-                )
+            )
+            services.append(
+                [
+                    service_v2_result.name,
+                    service_v2_result.id,
+                    service_v2_result.current_state,
+                    # TODO: change to email once https://github.com/anyscale/product/pull/18189 is merged
+                    service_v2_result.creator_id,
+                ]
+            )
 
         else:
             services_data = self._get_services_by_name(
@@ -467,21 +423,12 @@ class ServiceController(BaseController):
         self.log.info(f"Services:\n{table}")
 
     def archive(self, service_id: str):
-        if _is_v2_service_id(service_id):
-            raise click.ClickException(
-                "archive is not currently supported for v2 services."
-                "Please contact Anyscale support for more information."
-            )
-
-        self.job_controller.archive(service_id, None, is_service=True)
+        raise click.ClickException(
+            f"Archive {service_id} is not currently supported for v2 services."
+            "Please contact Anyscale support for more information."
+        )
 
     def rollback(self, service_id: str) -> None:
-        if not _is_v2_service_id(service_id):
-            raise click.ClickException(
-                "rollback is only supported for v2 services."
-                "Please contact Anyscale support for more information."
-            )
-
         service = self.api_client.rollback_service_api_v2_services_v2_service_id_rollback_post(
             service_id
         ).result
@@ -492,9 +439,10 @@ class ServiceController(BaseController):
         )
 
     def terminate(self, service_id: str) -> None:
-        if _is_v2_service_id(service_id):
-            self.api_client.terminate_service_api_v2_services_v2_service_id_terminate_post(
-                service_id
-            )
-        else:
-            self.job_controller.terminate(service_id, None, is_service=True)
+        self.api_client.terminate_service_api_v2_services_v2_service_id_terminate_post(
+            service_id
+        )
+        self.log.info(f"Service {service_id} terminate initiated.")
+        self.log.info(
+            f'View the service in the UI at {get_endpoint(f"/services/{service_id}")}'
+        )
