@@ -14,9 +14,13 @@ from google.cloud.storage.constants import (
 from google.iam.v1.policy_pb2 import Binding
 from googleapiclient.errors import HttpError
 
-from anyscale.cli_logger import BlockLogger
-from anyscale.client.openapi_client.models import CreateCloudResourceGCP
+from anyscale.cli_logger import CloudSetupLogger
+from anyscale.client.openapi_client.models import (
+    CloudAnalyticsEventCloudResource,
+    CreateCloudResourceGCP,
+)
 from anyscale.shared_anyscale_utils.conf import ANYSCALE_HOST
+from anyscale.utils.cloud_utils import CloudSetupError
 from anyscale.utils.gcp_managed_setup_utils import enable_project_apis
 from anyscale.utils.gcp_utils import (
     binding_from_dictionary,
@@ -39,6 +43,10 @@ from anyscale.utils.network_verification import (
 # projects/{project_id}/locations/{location}/instances/{instance_id}.
 _FILESTORE_NAME_REGEX_PATTERN = r"projects/(?P<project_id>[^/]+)/locations/(?P<location>[^/]+)/instances/(?P<instance_id>[^/]+)"
 
+# A subnet with this purpose must be in the VPC for private load balancers to work.
+# See: https://cloud.google.com/load-balancing/docs/proxy-only-subnets
+PROXY_ONLY_SUBNET_PURPOSE = "REGIONAL_MANAGED_PROXY"
+
 
 def verify_gcp_networking(
     factory: GoogleCloudClientFactory,
@@ -47,6 +55,7 @@ def verify_gcp_networking(
     cloud_region: str,
     logger: GCPLogger,
     strict: bool = False,
+    is_private_service_cloud: bool = False,
 ) -> bool:
     """Verify the existence and connectedness of the VPC & Subnet."""
     vpc_name = resources.gcp_vpc_id
@@ -77,14 +86,27 @@ def verify_gcp_networking(
         return False
 
     if subnet.network != vpc.self_link:
+        logger.internal.log_resource_error(
+            CloudAnalyticsEventCloudResource.GCP_SUBNET,
+            CloudSetupError.SUBNET_NOT_IN_VPC,
+        )
         logger.internal.error(f"Subnet {subnet_name} is not part of {vpc_name}!")
         return False
 
+    if is_private_service_cloud and not _vpc_has_proxy_only_subnet(
+        factory, project_id, cloud_region, vpc
+    ):
+        logger.internal.warning(
+            f"Could not find a subnet with purpose `{PROXY_ONLY_SUBNET_PURPOSE}` in the VPC {vpc_name}. A proxy-only subnet is required to run private Anyscale Services in your account. See https://cloud.google.com/load-balancing/docs/proxy-only-subnets for more details."
+        )
+        if strict:
+            return False
+
     return _gcp_subnet_has_enough_capacity(subnet, logger.internal)
 
 
 def _gcp_subnet_has_enough_capacity(
-    subnet: compute_v1.types.compute.Subnetwork, logger: BlockLogger
+    subnet: compute_v1.types.compute.Subnetwork, logger: CloudSetupLogger
 ) -> bool:
     """Verify if the subnet provided has a large enough IP address block."""
     if GCP_SUBNET_CAPACITY.verify_network_capacity(
@@ -94,6 +116,25 @@ def _gcp_subnet_has_enough_capacity(
     return False
 
 
+def _vpc_has_proxy_only_subnet(
+    factory: GoogleCloudClientFactory,
+    project_id: str,
+    cloud_region: str,
+    vpc: compute_v1.types.compute.Network,
+) -> bool:
+    # Check if there exists a subnet in the VPC and region with purpose `REGIONAL_MANAGED_PROXY`
+    subnets = factory.compute_v1.SubnetworksClient().list(
+        project=project_id, region=cloud_region
+    )
+    for subnet in subnets:
+        if (
+            subnet.network == vpc.self_link
+            and subnet.purpose == PROXY_ONLY_SUBNET_PURPOSE
+        ):
+            return True
+    return False
+
+
 def verify_gcp_project(  # noqa: PLR0911
     factory: GoogleCloudClientFactory,
     project_id: str,
@@ -111,6 +152,10 @@ def verify_gcp_project(  # noqa: PLR0911
         logger.log_resource_not_found_error("Project", project_id)
         return False
     if project.state != project.State.ACTIVE:
+        logger.internal.log_resource_error(
+            CloudAnalyticsEventCloudResource.GCP_PROJECT,
+            CloudSetupError.PROJECT_NOT_ACTIVE,
+        )
         logger.internal.error(
             f"Project {project_id} is in state: {project.state}, not active"
         )
@@ -159,6 +204,10 @@ def verify_gcp_project(  # noqa: PLR0911
         "Would you like to enable these APIs and proceed?"
     ):
         logger.spinner.start()
+        logger.internal.log_resource_error(
+            CloudAnalyticsEventCloudResource.GCP_PROJECT,
+            CloudSetupError.API_NOT_ENABLED,
+        )
         return False
 
     spinner_text = logger.spinner.text
@@ -167,7 +216,7 @@ def verify_gcp_project(  # noqa: PLR0911
 
     # enable all required apis, the operation is idompotent
     try:
-        enable_project_apis(factory, project_id)
+        enable_project_apis(factory, project_id, logger.internal)
     except ClickException as e:
         logger.internal.error(e.message)
         logger.spinner.text = spinner_text
@@ -200,7 +249,12 @@ def verify_gcp_access_service_account(
             logger.log_resource_not_found_error(
                 "Anyscale Access Service Account", anyscale_access_service_account
             )
-            return False
+        else:
+            logger.internal.log_resource_exception(
+                CloudAnalyticsEventCloudResource.GCP_SERVICE_ACCOUNT, e
+            )
+            logger.internal.error(str(e))
+        return False
 
     if service_account_iam_policy.get("bindings") is None or not check_policy_bindings(
         binding_from_dictionary(service_account_iam_policy["bindings"]),
@@ -250,8 +304,12 @@ def verify_gcp_dataplane_service_account(
             logger.log_resource_not_found_error(
                 "Dataplane Service Account", service_account
             )
-            return False
-        raise e
+        else:
+            logger.internal.log_resource_exception(
+                CloudAnalyticsEventCloudResource.GCP_SERVICE_ACCOUNT, e
+            )
+            logger.internal.error(str(e))
+        return False
 
     if resp["projectId"] != project_id:
         logger.internal.warning(
@@ -317,13 +375,17 @@ def verify_firewall_policy(  # noqa: PLR0911, PLR0912
                 project=project_id, firewall_policy=firewall_policy, region=cloud_region
             )
         except NotFound:
-            logger.log_resource_not_found_error("FirewallPolicy", firewall_policy)
+            logger.log_resource_not_found_error("Firewall Policy", firewall_policy)
             return False
 
     if not any(
         association.attachment_target.split("/")[-1] == vpc_name
         for association in firewall.associations
     ):
+        logger.internal.log_resource_error(
+            CloudAnalyticsEventCloudResource.GCP_FIREWALL_POLICY,
+            CloudSetupError.FIREWALL_NOT_ASSOCIATED_WITH_VPC,
+        )
         logger.internal.error(
             "Firewall policy {} is not associated with the VPC {}, but is associated with the following VPCs: {}".format(
                 firewall_policy, vpc_name, firewall.associations
@@ -358,6 +420,10 @@ def verify_firewall_policy(  # noqa: PLR0911, PLR0912
         logger.internal.error(
             "Firewall policy does not allow for internal communication, see https://cloud.google.com/vpc/docs/using-firewalls#common-use-cases-allow-internal for how to configure such a rule."
         )
+        logger.internal.log_resource_error(
+            CloudAnalyticsEventCloudResource.GCP_FIREWALL_POLICY,
+            CloudSetupError.INTERNAL_COMMUNICATION_NOT_ALLOWED,
+        )
         return False
     return True
 
@@ -419,6 +485,10 @@ def verify_filestore(
             if strict:
                 return False
     else:
+        logger.internal.log_resource_error(
+            CloudAnalyticsEventCloudResource.GCP_FILESTORE,
+            CloudSetupError.FILESTORE_NAME_MALFORMED,
+        )
         logger.internal.error(
             f"Failed to get filestore location, since filestore name doesn't match format {_FILESTORE_NAME_REGEX_PATTERN}!"
         )
@@ -427,6 +497,10 @@ def verify_filestore(
     file_store_networks = [v.network for v in file_store.networks]
     vpc_name = resources.gcp_vpc_id
     if not any(vpc_name == network.split("/")[-1] for network in file_store_networks):
+        logger.internal.log_resource_error(
+            CloudAnalyticsEventCloudResource.GCP_FILESTORE,
+            CloudSetupError.FILESTORE_NOT_CONNECTED_TO_VPC,
+        )
         logger.internal.error(
             f"Filestore is not connected to {vpc_name}, but to {file_store_networks}. "
             f"This cannot be edited on an existing Filestore instance. Please recreate the filestore and connect it to {vpc_name}."
