@@ -10,8 +10,8 @@ from anyscale.commands.anyscale_api.api_commands import anyscale_api
 from anyscale.commands.auth_commands import auth_cli
 from anyscale.commands.cloud_commands import cloud_cli
 from anyscale.commands.cluster_commands import cluster_cli
-from anyscale.commands.cluster_compute_commands import cluster_compute_cli
 from anyscale.commands.cluster_env_commands import cluster_env_cli
+from anyscale.commands.compute_config_commands import compute_config_cli
 from anyscale.commands.config_commands import config_cli
 from anyscale.commands.exec_commands import anyscale_exec
 from anyscale.commands.experimental_integrations_commands import (
@@ -19,6 +19,7 @@ from anyscale.commands.experimental_integrations_commands import (
 )
 from anyscale.commands.job_commands import job_cli
 from anyscale.commands.list_commands import list_cli
+from anyscale.commands.login_commands import anyscale_login, anyscale_logout
 from anyscale.commands.logs_commands import log_cli
 from anyscale.commands.migrate_commands import migrate_cli
 from anyscale.commands.project_commands import anyscale_init, project_cli
@@ -27,6 +28,7 @@ from anyscale.commands.service_commands import service_cli
 from anyscale.commands.session_commands_hidden import session_cli
 from anyscale.commands.workspace_commands import workspace_cli
 import anyscale.conf
+from anyscale.utils.cli_version_check_util import log_warning_if_version_needs_upgrade
 
 
 logger = logging.getLogger(__name__)
@@ -73,6 +75,7 @@ class AliasedGroup(click.Group):
 def cli(ctx: Any, version_flag: bool, show_json: bool) -> None:
     if version_flag:
         ctx.invoke(version_cli, show_json=show_json)
+    log_warning_if_version_needs_upgrade()
 
 
 @click.command(name="version", help="Display version of the anyscale CLI.")
@@ -113,18 +116,21 @@ cli.add_command(auth_cli)
 cli.add_command(anyscale_init)
 cli.add_command(anyscale_exec)
 cli.add_command(anyscale_help)
-cli.add_command(cluster_compute_cli)
+cli.add_command(compute_config_cli)
 
 # Commands to interact with the Anyscale API
 cli.add_command(anyscale_api)
 
 cli.add_command(log_cli)
+cli.add_command(anyscale_login)
+cli.add_command(anyscale_logout)
 
 ALIASES = {
     "h": anyscale_help,
     "schedules": schedule_cli,
     "jobs": job_cli,
     "services": service_cli,
+    "cluster-compute": compute_config_cli,
 }
 
 
