@@ -12,10 +12,6 @@ from anyscale.api_utils.job_logs_util import (
     _get_job_logs_from_storage_bucket,
     _get_logs_from_active_job_run,
 )
-from anyscale.api_utils.job_util import (
-    _is_job_on_v2_cloud,
-    _is_production_job_on_v2_cloud,
-)
 from anyscale.api_utils.exceptions.log_retrieval_errors import (
     ExpectedLogRetrievalError,
     LogRetrievalTimeoutError,
@@ -46,11 +42,12 @@ from anyscale.sdk.anyscale_client.models.apply_production_service_v2_model impor
     ApplyProductionServiceV2Model,
 )
 from anyscale.sdk.anyscale_client.models.cluster import Cluster
+from anyscale.sdk.anyscale_client.models.cluster_state import ClusterState
+from anyscale.sdk.anyscale_client.models.update_cluster import UpdateCluster
+
 from anyscale.sdk.anyscale_client.models.cluster_environment_build import (
     ClusterEnvironmentBuild,
 )
-from anyscale.sdk.anyscale_client.models.jobs_logs import JobsLogs
-from anyscale.sdk.anyscale_client.models.jobslogs_response import JobslogsResponse
 from anyscale.shared_anyscale_utils.headers import RequestHeaders
 from anyscale.cli_logger import BlockLogger, pad_string
 from anyscale.cluster_compute import get_selected_cloud_id_or_default
@@ -349,12 +346,40 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
             default_project = get_default_project(parent_cloud_id=parent_cloud_id)
             project_id = default_project.id
 
-        clusters = self.search_clusters(
+        clusters: Optional[List[Cluster]] = self.search_clusters(
             {"project_id": project_id, "name": {"equals": cluster_name}}
         ).results
 
         if clusters:
-            cluster = clusters[0]
+            
+            sorted_clusters_list = sorted(clusters, key=lambda x: x.created_at, reverse=True)
+            cluster: Cluster = sorted_clusters_list[0]
+
+            if cluster.state in [ClusterState.STARTINGUP, ClusterState.RUNNING, ClusterState.UPDATING, ClusterState.TERMINATING, ClusterState.AWAITINGSTARTUP]:
+                raise Exception(
+                    f"Cluster {cluster_name} in project {project_id} is in state {cluster.state}. "
+                    "Please terminate the cluster or use a new cluster name, then rerun launch_cluster."
+                )                
+            
+            if not cluster_environment_build_id:
+                cluster_environment_build_id = cluster.cluster_environment_build_id
+            
+            if not cluster_compute_id:
+                cluster_compute_id = cluster.cluster_compute_id
+
+            if not idle_timeout_minutes:
+                idle_timeout_minutes = cluster.idle_timeout_minutes
+
+            # Update cluster with new configurations
+            # Or use configurations from terminated cluster
+            update_cluster_config = UpdateCluster(
+                cluster_environment_build_id=cluster_environment_build_id,
+                cluster_compute_id=cluster_compute_id,
+                idle_timeout_minutes=idle_timeout_minutes,
+            )
+
+            self.update_cluster(cluster.id, update_cluster_config)
+            
         else:
             if not cluster_environment_build_id:
                 # Use default cluster environment build when starting cluster without specifying an id
@@ -379,6 +404,7 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
                     # Use default cluster compute when starting cluster without specifying an id
                     cluster_compute_id = self.get_default_cluster_compute().result.id
 
+
             create_cluster_payload: Dict[str, Any] = {
                 "name": cluster_name,
                 "project_id": project_id,
@@ -388,13 +414,16 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
             if idle_timeout_minutes:
                 create_cluster_payload["idle_timeout_minutes"] = idle_timeout_minutes
 
+            # Create cluster DB reference
             cluster = self.create_cluster(create_cluster_payload).result
 
+        # Start cluster
         start_operation = self.start_cluster(
             cluster.id,
             {
                 "cluster_environment_build_id": cluster_environment_build_id,
                 "cluster_compute_id": cluster_compute_id,
+                "idle_timeout_minutes": idle_timeout_minutes,
             },
         ).result
 
@@ -490,111 +519,6 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
         else:
             return self.get_cluster(operation.cluster_id).result
 
-    def fetch_job_logs(self, job_id: str) -> str:
-        """
-        Retrieves logs for a job run (eg. 'job_123').
-
-        This will try in following order until it finds a retrieval method that returns the logs:
-        1. Ray Dashboard API on the cluster that the job run is on
-           NOTE: The caller of this function must be able to reach the Ray dashboard host.
-        2. (only for anyscale v1 clouds) Anyscale backend / cache layer which stores logs for recently finished job runs
-        3. The storage bucket for the Anyscale cloud the job run (and its cluster) is on
-
-        Args:
-            job_id (str): ID of a job run
-
-        Returns:
-            str: All logs for the job run
-                (so far, if the job run is still running)
-        """
-        job_run: Job = self.get_job(job_id).result
-        get_job_logs_fns: List[Callable[..., str]] = [
-            *(
-                [lambda: asyncio.run(_get_logs_from_active_job_run(self, job_id))] if job_run.status == JobStatus.RUNNING else []
-            ),
-            lambda: self._fetch_job_logs_legacy(job_id),
-            lambda: asyncio.run(
-                _get_job_logs_from_storage_bucket(self, job_run_id=job_id)
-            ),
-        ]
-        logs = ""
-        # Return logs from the first retrieval method that has non-empty logs
-        for fn in get_job_logs_fns:
-            with contextlib.suppress(ExpectedLogRetrievalError):
-                logs = fn()
-                if logs:
-                    return logs
-        return logs
-
-    def _fetch_job_logs_legacy(self, job_id: str) -> str:
-        """
-        Retrieves logs for a Ray Job or Interactive Session.
-        This function may take several minutes if the Cluster this Job ran on has been terminated.
-
-        Args:
-            job_id - ID of the Job
-
-        Returns
-            Log output for the Job as a string
-
-        Raises
-            UnsupportedLogRetrievalMethodError if on an Anyscale v2 cloud
-            Exception if we fail to fetch logs
-        """
-        if _is_job_on_v2_cloud(self, job_id):
-            raise UnsupportedLogRetrievalMethodError(
-                "Logs are not stored Anyscale-side on clouds set up with Anyscale v2."
-            )
-
-        # Timeout in 5 minutes
-        timeout = time() + 300
-
-        logs = self.get_job_logs(job_id).result
-
-        while not logs.ready:
-            if time() > timeout:
-                raise LogRetrievalTimeoutError(f"Failed to get logs from Job {job_id}")
-
-            sleep(15)
-            logs = self.get_job_logs(job_id).result
-
-        # Logs will be empty if on anyscale v1 and job logs are no longer in cache
-        return _remove_ansi_escape_sequences(logs.logs)
-
-    @deprecated("`get_production_job_logs()` is deprecated. "
-                "Use `fetch_production_job_logs()` to retrieve the logs string instead.")
-    def get_production_job_logs(self, job_id: str) -> JobslogsResponse:
-        """
-        DEPRECATED: Please use `fetch_production_job_logs` to retrieve
-        the logs string instead.
-
-        Retrieves logs for latest run of a Production Job.
-
-        Args:
-            job_id - ID of the Job
-
-        Returns
-            Response containing the log output for the job
-
-        Raises
-            Exception if we fail to fetch logs
-        """
-
-        return JobslogsResponse(
-            result=JobsLogs(
-                logs=self.fetch_production_job_logs(job_id),
-                ready=True,
-            )
-        )
-
-    def _get_production_job_logs_legacy(self, job_id: str) -> JobslogsResponse:
-        latest_job_run_id = self.get_production_job(
-            production_job_id=job_id
-        ).result.last_job_run_id
-        if not latest_job_run_id:
-            raise Exception(f"Production Job {job_id} does not have a job run.")
-
-        return self.get_job_logs(latest_job_run_id)
 
     def fetch_production_job_logs(self, job_id: str) -> str:
         """
@@ -619,7 +543,6 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
             *(
                 [lambda: asyncio.run(_get_logs_from_running_production_job(self, job_id))] if job.state.current_state == HaJobStates.RUNNING else []
             ),
-            lambda: self._fetch_production_job_logs_legacy(job_id),
             lambda: asyncio.run(_get_job_logs_from_storage_bucket(self, job_id=job_id)),
         ]
         logs = ""
@@ -631,42 +554,6 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
                     return logs
         return logs
 
-    def _fetch_production_job_logs_legacy(self, job_id: str) -> str:
-        """
-        Retrieves logs for latest run of a Production Job.
-        Waits 5 min for logs to be ready.
-        This function may take several minutes if the Cluster this Job ran on has been terminated.
-
-        Args:
-            job_id - ID of the Job
-
-        Returns
-            Log output for the Job as a string
-
-        Raises
-            UnsupportedLogRetrievalMethodError if on an Anyscale v2 cloud
-            Exception if we fail to fetch logs
-        """
-        if _is_production_job_on_v2_cloud(self, job_id):
-            raise UnsupportedLogRetrievalMethodError(
-                "Logs are not stored Anyscale-side on clouds set up with Anyscale v2."
-            )
-
-        # Timeout in 5 minutes
-        timeout = time() + 300
-
-        logs = self._get_production_job_logs_legacy(job_id).result
-
-        while not logs.ready:
-            if time() > timeout:
-                raise Exception(f"Failed to get logs from Job {job_id}")
-
-            sleep(15)
-            logs = self._get_production_job_logs_legacy(job_id).result
-
-        # Logs will be empty if on anyscale v1 and job logs are no longer in cache
-        return _remove_ansi_escape_sequences(logs.logs)
-
     def create_job(self, create_production_job, **kwargs):
         _upload_and_rewrite_working_dir_in_create_production_job(create_production_job)
         return super().create_job(create_production_job, **kwargs)
