@@ -33,8 +33,11 @@ import requests
 from requests import Response
 
 from anyscale.authenticate import get_auth_api_client
-from anyscale.cli_logger import BlockLogger
+from anyscale.cli_logger import BlockLogger, CloudSetupLogger
 from anyscale.client.openapi_client.api.default_api import DefaultApi as ProductApi
+from anyscale.client.openapi_client.models.cloud_analytics_event_cloud_resource import (
+    CloudAnalyticsEventCloudResource,
+)
 from anyscale.client.openapi_client.models.decorated_compute_template import (
     DecoratedComputeTemplate,
 )
@@ -218,7 +221,9 @@ def _get_aws_efs_mount_target_ip(boto3_session: Any, efs_id: str) -> Optional[st
         raise e
 
 
-def _get_subnet(subnet_arn: str, region: str) -> Optional[Boto3Resource]:
+def _get_subnet(
+    subnet_arn: str, region: str, logger: CloudSetupLogger
+) -> Optional[Boto3Resource]:
     ec2 = _resource("ec2", region)  # TODO: take a resource as an argument
     subnet = ec2.Subnet(subnet_arn)  # type: ignore
     try:
@@ -227,6 +232,10 @@ def _get_subnet(subnet_arn: str, region: str) -> Optional[Boto3Resource]:
     except ClientError as e:
         if e.response["Error"]["Code"] == "InvalidSubnetID.NotFound":
             return None
+        else:
+            logger.log_resource_exception(
+                CloudAnalyticsEventCloudResource.AWS_SUBNET, e
+            )
         raise e
 
 
@@ -799,8 +808,8 @@ def filter_actions_from_policy_document(
         action_filter = lambda statement: statement["Effect"] == "Allow"  # noqa: E731
     return {
         action
-        for statement in _coerce_to_list(policy_document["Statement"])
-        for action in _coerce_to_list(statement["Action"])
+        for statement in _coerce_to_list(policy_document.get("Statement", {}))
+        for action in _coerce_to_list(statement.get("Action"))
         if action_filter(statement)
     }
 
@@ -831,6 +840,8 @@ def contains_control_plane_role(
     assume_role_policy_document: Dict[str, Any], anyscale_aws_account: str
 ) -> bool:
     def action_filter(statement: dict):
+        if not statement:
+            return False
         # Ensure it is `Allow` & `sts:AssumeRole`
         if (
             statement["Effect"] != "Allow"
@@ -857,6 +868,34 @@ def contains_control_plane_role(
     )
 
 
+def verify_data_plane_role_assume_role_policy(
+    assume_role_policy_document: Dict[str, Any]
+) -> bool:
+    def action_filter(statement: dict):
+        # Ensure it is `Allow` & `sts:AssumeRole`
+        if not statement:
+            return False
+        if (
+            statement["Effect"] != "Allow"
+            or statement.get("Action") != "sts:AssumeRole"
+        ):
+            return False
+
+        return any(
+            service == "ec2.amazonaws.com"
+            for service in _coerce_to_list(statement["Principal"].get("Service"))
+        )
+
+    return (
+        len(
+            filter_actions_from_policy_document(
+                assume_role_policy_document, action_filter
+            )
+        )
+        > 0
+    )
+
+
 T = TypeVar("T")
 
 
