@@ -15,7 +15,8 @@ from google.iam.v1.policy_pb2 import Binding
 from googleapiclient.errors import HttpError
 import yaml
 
-from anyscale.cli_logger import BlockLogger
+from anyscale.cli_logger import CloudSetupLogger
+from anyscale.client.openapi_client.models import CloudAnalyticsEventCloudResource
 import anyscale.conf
 import anyscale.shared_anyscale_utils.conf as shared_anyscale_conf
 from anyscale.utils.gcp_utils import GCP_REQUIRED_APIS, GoogleCloudClientFactory
@@ -50,7 +51,9 @@ def append_project_iam_policy(
         raise ClickException(f"Failed to set IAM policy for project {project_id}: {e}")
 
 
-def enable_project_apis(factory: GoogleCloudClientFactory, project_id: str):
+def enable_project_apis(
+    factory: GoogleCloudClientFactory, project_id: str, logger: CloudSetupLogger
+):
     """ Automatically enable APIs that Anyscale needs.
     """
     try:
@@ -71,6 +74,7 @@ def enable_project_apis(factory: GoogleCloudClientFactory, project_id: str):
             f"Enable APIs for project {project_id}",
         )
     except HttpError as e:
+        logger.log_resource_exception(CloudAnalyticsEventCloudResource.GCP_PROJECT, e)
         raise ClickException(f"Failed to enable APIs for project {project_id}: {e}")
 
 
@@ -159,7 +163,7 @@ def create_workload_identity_pool(
     factory: GoogleCloudClientFactory,
     project_id: str,
     pool_id: str,
-    logger: BlockLogger,
+    logger: CloudSetupLogger,
     display_name: str = "a workload identity pool",
     description: str = "a workload identity pool",
 ):
@@ -208,7 +212,7 @@ def create_anyscale_aws_provider(
     provider_id: str,
     aws_account_id: str,
     display_name: str,
-    logger: BlockLogger,
+    logger: CloudSetupLogger,
 ):
     """ Create a GCP Workload Identity Provider for Anyscale cross account access.
     The functionality is notcurrently supported by GCP Deployment Manager.
@@ -364,7 +368,7 @@ def configure_firewall_policy(
 
 
 def delete_workload_identity_pool(
-    factory: GoogleCloudClientFactory, pool_name: str, logger: BlockLogger
+    factory: GoogleCloudClientFactory, pool_name: str, logger: CloudSetupLogger
 ):
     service = factory.build("iam", "v1").projects().locations().workloadIdentityPools()
 
