@@ -10,7 +10,8 @@ from anyscale.commands.cloud_commands import setup_cloud
 @pytest.mark.parametrize(
     "use_legacy_stack", [True, False],
 )
-def test_cloud_setup(use_legacy_stack):
+@pytest.mark.parametrize("enable_head_node_fault_tolerance", [True, False])
+def test_cloud_setup(use_legacy_stack, enable_head_node_fault_tolerance):
     runner = CliRunner()
     mock_cloud_controller = Mock()
     mock_setup_managed_cloud = Mock()
@@ -30,6 +31,9 @@ def test_cloud_setup(use_legacy_stack):
     if use_legacy_stack:
         args.append("--use-legacy-stack")
 
+    if enable_head_node_fault_tolerance:
+        args.append("--enable-head-node-fault-tolerance")
+
     with patch(
         "anyscale.commands.cloud_commands.CloudController", new=mock_cloud_controller,
     ):
@@ -41,4 +45,5 @@ def test_cloud_setup(use_legacy_stack):
         name=name,
         functional_verify=None,
         cluster_management_stack_version=cluster_management_stack_version,
+        enable_head_node_fault_tolerance=enable_head_node_fault_tolerance,
     )
