@@ -130,12 +130,15 @@ def test_start_cluster_if_required(
 
 @pytest.mark.parametrize("cluster_exists", [True, False])
 @pytest.mark.parametrize("start_required", [True, False])
-@pytest.mark.parametrize("idle_timeout", [None, 100])
+@pytest.mark.parametrize(
+    ("idle_timeout", "expected_idle_timeout"), [(None, 120), (100, 100)]
+)
 def test_create_or_update_session_data(
     mock_prepare_cluster_block,
     cluster_exists: bool,
     start_required: bool,
     idle_timeout: Optional[int],
+    expected_idle_timeout: int,
 ):
     mock_cluster = Mock(state="Running", id="test_cluster_id")
     mock_get_cluster = Mock(
@@ -170,7 +173,7 @@ def test_create_or_update_session_data(
                 project_id="test_project_id",
                 cluster_environment_build_id="test_build_id",
                 cluster_compute_id="test_compute_template_id",
-                idle_timeout_minutes=idle_timeout,
+                idle_timeout_minutes=expected_idle_timeout,
                 allow_public_internet_traffic=None,
             )
         )
@@ -404,7 +407,8 @@ def test_get_cluster_compute_id(
     cluster_compute_dict: Optional[Dict[str, str]],
     cloud_name: Optional[str],
 ):
-    mock_prepare_cluster_block._get_cloud_id = Mock(return_value="test_cloud_id")
+    cloud_id = "test_cloud_id"
+    mock_get_selected_cloud_id_or_default = Mock(return_value=cloud_id)
     mock_default_config_obj = Mock()
     mock_config_obj_from_cluster_compute_dict = Mock()
     mock_prepare_cluster_block.anyscale_api_client.get_default_compute_config = Mock(
@@ -422,6 +426,7 @@ def test_get_cluster_compute_id(
         ComputeTemplateConfig=Mock(
             return_value=mock_config_obj_from_cluster_compute_dict
         ),
+        get_selected_cloud_id_or_default=mock_get_selected_cloud_id_or_default,
     ):
         observed_result = mock_prepare_cluster_block._get_cluster_compute_id(
             "test_project_id", cluster_compute_name, cluster_compute_dict, cloud_name
@@ -436,11 +441,8 @@ def test_get_cluster_compute_id(
         if cluster_compute_dict:
             mock_config_obj = mock_config_obj_from_cluster_compute_dict
         else:
-            mock_prepare_cluster_block._get_cloud_id.assert_called_once_with(
-                "test_project_id", cloud_name
-            )
             mock_prepare_cluster_block.anyscale_api_client.get_default_compute_config.assert_called_once_with(
-                "test_cloud_id"
+                cloud_id
             )
             mock_config_obj = mock_default_config_obj
         mock_prepare_cluster_block._register_compute_template.assert_called_once_with(
@@ -496,51 +498,6 @@ def test_is_equal_cluster_compute(mock_prepare_cluster_block):
     )
 
 
-@pytest.mark.parametrize("cloud_name", [None, "test_cloud_name"])
-@pytest.mark.parametrize("default_cloud_exists", [True, False])
-def test_get_cloud_id(
-    mock_prepare_cluster_block, cloud_name: Optional[str], default_cloud_exists: bool
-):
-    mock_get_organization_default_cloud = Mock(
-        return_value="default_cloud_name" if default_cloud_exists else None
-    )
-    mock_get_last_used_cloud = Mock(return_value="last_used_cloud_name")
-    mock_get_cloud_id_and_name = Mock(return_value=("mock_cloud_id", Mock()))
-
-    with patch.multiple(
-        "anyscale.connect_utils.prepare_cluster",
-        get_cloud_id_and_name=mock_get_cloud_id_and_name,
-        get_organization_default_cloud=mock_get_organization_default_cloud,
-        get_last_used_cloud=mock_get_last_used_cloud,
-    ):
-        assert (
-            mock_prepare_cluster_block._get_cloud_id("test_project_id", cloud_name)
-            == "mock_cloud_id"
-        )
-
-    if cloud_name:
-        mock_get_cloud_id_and_name.assert_called_once_with(
-            mock_prepare_cluster_block.api_client, cloud_name=cloud_name
-        )
-    elif default_cloud_exists:
-        mock_get_organization_default_cloud.assert_called_once_with(
-            mock_prepare_cluster_block.api_client
-        )
-        mock_get_cloud_id_and_name.assert_called_once_with(
-            mock_prepare_cluster_block.api_client, cloud_name="default_cloud_name"
-        )
-    else:
-        mock_get_organization_default_cloud.assert_called_once_with(
-            mock_prepare_cluster_block.api_client
-        )
-        mock_get_last_used_cloud.assert_called_once_with(
-            "test_project_id", mock_prepare_cluster_block.anyscale_api_client
-        )
-        mock_get_cloud_id_and_name.assert_called_once_with(
-            mock_prepare_cluster_block.api_client, cloud_name="last_used_cloud_name"
-        )
-
-
 @pytest.mark.parametrize("build_matches", [True, False])
 @pytest.mark.parametrize("cluster_compute_matches", [True, False])
 @pytest.mark.parametrize("allow_public_internet_traffic_matches", [True, False])
@@ -612,7 +569,7 @@ def test_init(
     mock_cluster.name = "test_cluster_name"
     mock_build_cluster_env_if_needed = Mock(return_value=cluster_env_name)
     mock_get_cluster_build = Mock(return_value=Mock(id="mock_build_id"))
-    mock_get_cloud_id = Mock(return_value="mock_cloud_id")
+    mock_get_selected_cloud_id_or_default = Mock(return_value="mock_cloud_id")
     mock_get_cluster_compute_id = Mock(return_value="mock_cluster_compute_id")
     mock_wait_for_app_build = Mock()
     mock_start_or_create_cluster = Mock(return_value="test_cluster_name")
@@ -630,7 +587,6 @@ def test_init(
         _start_or_create_cluster=mock_start_or_create_cluster,
         _wait_for_app_build=mock_wait_for_app_build,
         _get_cluster_compute_id=mock_get_cluster_compute_id,
-        _get_cloud_id=mock_get_cloud_id,
         _get_cluster_build=mock_get_cluster_build,
         _build_cluster_env_if_needed=mock_build_cluster_env_if_needed,
         _get_prepare_cluster_action=mock_get_prepare_cluster_action,
@@ -638,6 +594,7 @@ def test_init(
         "anyscale.connect_utils.prepare_cluster",
         get_cluster=Mock(return_value=mock_cluster),
         get_auth_api_client=Mock(return_value=Mock()),
+        get_selected_cloud_id_or_default=mock_get_selected_cloud_id_or_default,
     ):
         prepare_cluster_block = PrepareClusterBlock(
             project_id="test_project_id",
@@ -682,7 +639,6 @@ def test_init(
         else:
             build_id = mock_cluster.build_id
 
-        mock_get_cloud_id.assert_called_once_with("test_project_id", "test_cloud_name")
         if cluster_compute_name:
             mock_get_cluster_compute_id.assert_called_once_with(
                 "test_project_id",
