@@ -1,10 +1,14 @@
+from contextlib import nullcontext
 from datetime import datetime
 import tempfile
+from typing import Any, Callable, Optional
 from unittest.mock import Mock, patch
 
+from click import ClickException
 import pytest
 import yaml
 
+from anyscale.cluster_env import get_build_from_cluster_env_identifier
 from anyscale.controllers.cluster_env_controller import ClusterEnvController
 from anyscale.sdk.anyscale_client import (
     CreateBYODClusterEnvironment,
@@ -12,6 +16,49 @@ from anyscale.sdk.anyscale_client import (
 )
 
 
+def get_imported_function_name(func: Callable[..., Any]) -> str:
+    return ".".join([ClusterEnvController.__module__, func.__name__])
+
+
+@pytest.mark.parametrize("cluster_env_name", ["mock_cluster_env_name", None])
+@pytest.mark.parametrize("build_id", ["build_id_from_cli", None])
+def test_get(
+    mock_auth_api_client, cluster_env_name: Optional[str], build_id: Optional[str]
+) -> None:
+    cluster_env_controller = ClusterEnvController()
+    example_cluster_env_config = '{ "foo": "bar" }'
+    cluster_env_controller.api_client.get_build_api_v2_builds_build_id_get = Mock(
+        return_value=Mock(result=Mock(config_json=example_cluster_env_config))
+    )
+    mock_build_id_from_cluster_env = "build_id_from_cluster_env"
+    possible_error_if_both_or_neither_arg_provided = (
+        pytest.raises(ClickException)
+        if bool(cluster_env_name) == bool(build_id)
+        else nullcontext()
+    )
+    with patch(
+        get_imported_function_name(get_build_from_cluster_env_identifier),
+        new=Mock(return_value=Mock(id=mock_build_id_from_cluster_env)),
+    ) as mock_get_build_from_cluster_env_identifier, possible_error_if_both_or_neither_arg_provided as e:
+        cluster_env_controller.get(cluster_env_name, build_id)
+    if not e:
+        if cluster_env_name:
+            mock_get_build_from_cluster_env_identifier.assert_called_with(
+                cluster_env_name, cluster_env_controller.anyscale_api_client
+            )
+            mock_build_id = mock_build_id_from_cluster_env
+        else:
+            mock_get_build_from_cluster_env_identifier.assert_not_called()
+            mock_build_id = build_id  # type: ignore
+        cluster_env_controller.api_client.get_build_api_v2_builds_build_id_get.assert_called_once_with(
+            mock_build_id
+        )
+    else:
+        assert "Please only provide one of" in e.value.message
+        mock_get_build_from_cluster_env_identifier.assert_not_called()
+        cluster_env_controller.api_client.get_build_api_v2_builds_build_id_get.assert_not_called()
+
+
 def test_list_builds(mock_auth_api_client,):
     with patch.multiple(
         "anyscale.authenticate.AuthenticationBlock",
