@@ -6,7 +6,7 @@ import tempfile
 import time
 from types import SimpleNamespace
 from typing import Any, Dict, List, Optional, Tuple, Type
-from unittest.mock import MagicMock, Mock, mock_open, patch
+from unittest.mock import ANY, call, MagicMock, Mock, mock_open, patch
 
 from aiohttp import ClientResponseError, ClientSession, WSMsgType
 from asynctest import CoroutineMock
@@ -15,12 +15,7 @@ from pydantic import ValidationError
 import pytest
 import yaml
 
-from anyscale.api_utils.exceptions.log_retrieval_errors import (
-    ExpectedLogRetrievalError,
-    UnsupportedLogRetrievalMethodError,
-)
 from anyscale.api_utils.job_logs_util import _get_job_logs_from_storage_bucket
-from anyscale.api_utils.job_util import _is_production_job_on_v2_cloud
 from anyscale.api_utils.logs_util import _stream_log_from_ray_websocket
 from anyscale.client.openapi_client.models.create_internal_production_job import (
     CreateInternalProductionJob,
@@ -34,7 +29,6 @@ from anyscale.controllers.job_controller import (
     JobController,
     LogProvider,
     LogsLogger,
-    MiniJobRun,
 )
 from anyscale.models.job_model import _working_dir_is_remote_uri, JobConfig
 from anyscale.sdk.anyscale_client.models.compute_template import ComputeTemplate
@@ -337,9 +331,6 @@ def test_submit_job(
 @pytest.mark.parametrize("name", ["mock_job_name", None])
 @pytest.mark.parametrize("job_id", ["mock_job_id", None])
 @pytest.mark.parametrize("project_id", ["mock_project_id", None])
-@pytest.mark.parametrize(
-    "is_service", [False, True]
-)  # Whether command should list jobs or services
 @pytest.mark.parametrize(
     "passed_service_id", [False, True]
 )  # Whether `job_id` is id of job or service
@@ -350,7 +341,6 @@ def test_list_jobs(  # noqa: PLR0913
     name: Optional[str],
     job_id: Optional[str],
     project_id: Optional[str],
-    is_service: bool,
     passed_service_id: bool,
     include_archived: bool,
 ) -> None:
@@ -373,7 +363,7 @@ def test_list_jobs(  # noqa: PLR0913
         )
     )
 
-    if is_service != passed_service_id and job_id is not None:
+    if passed_service_id and job_id is not None:
         # Raise error if trying to list id that is not valid for the command.
         # Eg: job_id providied for `anyscale service list`
         with pytest.raises(click.ClickException):
@@ -382,7 +372,6 @@ def test_list_jobs(  # noqa: PLR0913
                 name=name,
                 job_id=job_id,
                 project_id=project_id,
-                is_service=is_service,
                 include_archived=include_archived,
                 max_items=20,
             )
@@ -393,7 +382,6 @@ def test_list_jobs(  # noqa: PLR0913
             name=name,
             job_id=job_id,
             project_id=project_id,
-            is_service=is_service,
             include_archived=include_archived,
             max_items=20,
         )
@@ -416,7 +404,7 @@ def test_list_jobs(  # noqa: PLR0913
             creator_id=creator_id,
             name=name,
             project_id=project_id,
-            type_filter="SERVICE" if is_service else "BATCH_JOB",
+            type_filter="BATCH_JOB",
             archive_status="ALL" if include_archived else "NOT_ARCHIVED",
             count=10,
         )
@@ -424,7 +412,7 @@ def test_list_jobs(  # noqa: PLR0913
             creator_id=creator_id,
             name=name,
             project_id=project_id,
-            type_filter="SERVICE" if is_service else "BATCH_JOB",
+            type_filter="BATCH_JOB",
             archive_status="ALL" if include_archived else "NOT_ARCHIVED",
             count=10,
             paging_token="paging_token",
@@ -435,16 +423,10 @@ def test_list_jobs(  # noqa: PLR0913
         )
 
 
-@pytest.mark.parametrize(
-    "is_service", [False, True]
-)  # Whether command should list jobs or services
 @pytest.mark.parametrize("name", ["mock_job_name", None])
 @pytest.mark.parametrize("id", ["mock_job_id", None])
 def test_terminate_job(
-    mock_auth_api_client,
-    name: Optional[str],
-    id: Optional[str],  # noqa: A002
-    is_service: bool,
+    mock_auth_api_client, name: Optional[str], id: Optional[str],  # noqa: A002
 ) -> None:
     job_controller = JobController()
     job_controller.api_client.list_decorated_jobs_api_v2_decorated_ha_jobs_get = Mock(
@@ -455,28 +437,24 @@ def test_terminate_job(
     )
     if not name and not id:
         with pytest.raises(click.ClickException):
-            job_controller.terminate(id, name, is_service)
+            job_controller.terminate(id, name)
         return
     else:
-        job_controller.terminate(id, name, is_service)
+        job_controller.terminate(id, name)
 
     job_controller.api_client.terminate_job_api_v2_decorated_ha_jobs_production_job_id_terminate_post.assert_called_once_with(
         "mock_job_id"
     )
     if name is not None and id is None:
         job_controller.api_client.list_decorated_jobs_api_v2_decorated_ha_jobs_get.assert_called_once_with(
-            name=name, type_filter="SERVICE" if is_service else "BATCH_JOB",
+            name=name, type_filter="BATCH_JOB",
         )
 
 
-@pytest.mark.parametrize("is_service", [False, True])
 @pytest.mark.parametrize("name", ["mock_job_name", None])
 @pytest.mark.parametrize("id", ["mock_job_id", None])
 def test_archive_job(
-    mock_auth_api_client,
-    name: Optional[str],
-    id: Optional[str],  # noqa: A002
-    is_service: bool,
+    mock_auth_api_client, name: Optional[str], id: Optional[str],  # noqa: A002
 ) -> None:
     job_controller = JobController()
     job_controller.api_client.list_decorated_jobs_api_v2_decorated_ha_jobs_get = Mock(
@@ -487,17 +465,17 @@ def test_archive_job(
     )
     if not name and not id:
         with pytest.raises(click.ClickException):
-            job_controller.archive(id, name, is_service)
+            job_controller.archive(id, name)
         return
     else:
-        job_controller.archive(id, name, is_service)
+        job_controller.archive(id, name)
 
     job_controller.api_client.archive_job_api_v2_decorated_ha_jobs_production_job_id_archive_post.assert_called_once_with(
         "mock_job_id"
     )
     if name is not None and id is None:
         job_controller.api_client.list_decorated_jobs_api_v2_decorated_ha_jobs_get.assert_called_once_with(
-            name=name, type_filter="SERVICE" if is_service else "BATCH_JOB",
+            name=name, type_filter="BATCH_JOB",
         )
 
 
@@ -1110,110 +1088,6 @@ def test_print_logs_for_inactive_job_run(mock_auth_api_client) -> None:
     )
 
 
-@pytest.mark.parametrize(
-    "mode",
-    ["empty", "single", "paginate", "follow", "flush_success", "wait_for_running"],
-)
-def test_print_logs_legacy(mock_auth_api_client, capsys, mode) -> None:
-    job_controller = JobController(log=FakeLogger())
-    fake_log_provider_cls = fake_log_provider(mode)
-
-    state = {"flush_success": "SUCCESS", "wait_for_running": "PENDING"}.get(
-        mode, "RUNNING"
-    )
-
-    job_controller._get_formatted_latest_job_run = Mock(  # type: ignore
-        return_value=MiniJobRun(
-            last_job_run_id="mock_job_id", job_state=state, error=None
-        )
-    )
-
-    def reset(*args, **kwargs):
-        job_controller._get_formatted_latest_job_run = Mock(  # type: ignore
-            return_value=MiniJobRun(
-                last_job_run_id="mock_job_id", job_state="SUCCESS", error=None
-            )
-        )
-
-    job_controller._wait_for_job_running = Mock(side_effect=reset)  # type: ignore
-    job_controller.anyscale_api_client.get_job_logs_query_info = Mock(
-        return_value=Mock(
-            result=Mock(
-                loki_dns_name="abc.com",
-                access_token="secret-key",
-                loki_query="query-abc",
-            )
-        )
-    )
-
-    def do_loki_logs() -> None:
-        job_controller._print_logs_legacy(
-            job=Mock(id="mock_job_id"),
-            should_follow=mode in ["follow", "flush_success", "wait_for_running"],
-            log_provider_cls=fake_log_provider_cls,
-        )
-
-    if mode == "empty":
-        do_loki_logs()
-        assert capsys.readouterr().out.strip() == ""
-    elif mode == "single":
-        do_loki_logs()
-        assert capsys.readouterr().out.strip() == "start\nend"
-    elif mode == "paginate":
-        do_loki_logs()
-        assert capsys.readouterr().out.strip() == "entry-1\nentry-2"
-    elif mode == "follow":
-        with pytest.raises(IndexError):  # controller should continue to query
-            do_loki_logs()
-        out = capsys.readouterr().out.strip()
-        assert out == "finally"
-    elif mode == "flush_success":
-        do_loki_logs()
-        out = capsys.readouterr().out.strip()
-        assert out == "finally"
-    elif mode == "wait_for_running":
-        with pytest.raises(IndexError):  # controller should continue to query
-            do_loki_logs()
-        assert job_controller._wait_for_job_running.call_count == 1
-        out = capsys.readouterr().out.strip()
-        assert out == "finally"
-    else:
-        raise Exception("unreachable")
-
-
-def test_print_logs_legacy_errors_when_job_on_v2_cloud(mock_auth_api_client) -> None:
-    job_controller = JobController()
-    mock_job = Mock(id="prodjob_123")
-    with patch.object(
-        job_controller_module,
-        _is_production_job_on_v2_cloud.__name__,  # type: ignore
-        return_value=True,
-    ) as mock_is_production_job_on_v2_cloud, pytest.raises(
-        UnsupportedLogRetrievalMethodError, match="Logs are not stored Anyscale-side"
-    ):
-        job_controller._print_logs_legacy(mock_job)
-    mock_is_production_job_on_v2_cloud.assert_called_once_with(
-        job_controller.anyscale_api_client, mock_job.id
-    )
-
-
-def test_print_logs_legacy_errors_when_not_logged_at_all(mock_auth_api_client) -> None:
-    job_controller = JobController()
-    mock_job = Mock(
-        state=Mock(current_state=HaJobStates.TERMINATED, error=None),
-        last_job_run_id="job_123",
-    )
-    fake_log_provider_cls = fake_log_provider("empty")
-    with patch.object(
-        job_controller_module,
-        _is_production_job_on_v2_cloud.__name__,  # type: ignore
-        return_value=False,
-    ), pytest.raises(ExpectedLogRetrievalError):
-        job_controller._print_logs_legacy(
-            mock_job, log_provider_cls=fake_log_provider_cls
-        )
-
-
 def test_logs(mock_auth_api_client) -> None:
     job_controller = JobController()
     prod_job_id = "prodjob_123"
@@ -1225,11 +1099,16 @@ def test_logs(mock_auth_api_client) -> None:
     )
     job_controller._wait_for_a_job_run = Mock(return_value=mock_job)  # type: ignore
     job_controller._print_logs_for_active_job_run = mock_stream_logs = Mock()  # type: ignore
-    job_controller._print_logs_legacy = mock_loki_logs = Mock()  # type: ignore
     job_controller._print_logs_for_inactive_job_run = mock_download_logs = Mock()  # type: ignore
+    mock_ff_response = Mock()
+    mock_ff_response.result = Mock()
+    mock_ff_response.result.is_on = False
+    job_controller.api_client.check_is_feature_flag_on_api_v2_userinfo_check_is_feature_flag_on_get = Mock(
+        return_value=mock_ff_response
+    )
 
     def reset_mocks() -> None:
-        for mock in [mock_stream_logs, mock_loki_logs, mock_download_logs]:
+        for mock in [mock_stream_logs, mock_download_logs]:
             mock.reset_mock()
 
     def do_assertions(
@@ -1244,26 +1123,16 @@ def test_logs(mock_auth_api_client) -> None:
         for mock in not_called:
             mock.assert_not_called()
 
-    # Test Loki logs and does not follow by default if job is not in RUNNING state
+    # Test default if job is not in RUNNING state
     job_controller.logs(job_id=prod_job_id)
-    do_assertions(not_called=[mock_stream_logs, mock_download_logs])
-    mock_loki_logs.assert_called_once_with(mock_job, False)
-
-    # Test download logs (ie. falls back) if Loki has no logs (raises `ExpectedLogRetrievalError`)
-    reset_mocks()
-    job_controller._print_logs_legacy.side_effect = ExpectedLogRetrievalError
-    job_controller.logs(job_id=prod_job_id)
-    do_assertions(
-        called=[mock_loki_logs, mock_download_logs], not_called=[mock_stream_logs]
-    )
+    do_assertions(not_called=[mock_stream_logs])
+    mock_download_logs.assert_called_once_with(last_job_run_id)
 
     # Test stream if job is RUNNING
     reset_mocks()
     mock_job.state.current_state = HaJobStates.RUNNING
     job_controller.logs(job_id=prod_job_id)
-    do_assertions(
-        called=[mock_stream_logs], not_called=[mock_loki_logs, mock_download_logs]
-    )
+    do_assertions(called=[mock_stream_logs], not_called=[mock_download_logs])
 
     # Test `all_attempts = True`
     reset_mocks()
@@ -1276,26 +1145,99 @@ def test_logs(mock_auth_api_client) -> None:
     mock_stream_logs.assert_called_once_with(last_job_run_id, True)
 
 
-def test_wait_for_job_running(mock_auth_api_client) -> None:
-    job_controller = JobController(log=FakeLogger())
-    i = 0
+def test_logs_streaming(mock_auth_api_client) -> None:
+    job_controller = JobController()
+    prod_job_id = "prodjob_123"
+    last_job_run_id = "job_123"
+    mock_job = Mock(
+        id=prod_job_id,
+        last_job_run_id=last_job_run_id,
+        state=Mock(current_state=HaJobStates.RUNNING),
+    )
+    job_controller.log = Mock()
+    job_controller.log.spinner = LogsLogger().spinner
+    job_controller._wait_for_a_job_run = Mock(return_value=mock_job)  # type: ignore
+    mock_ff_response = Mock()
+    mock_ff_response.result = Mock()
+    mock_ff_response.result.is_on = True
+    job_controller.api_client.check_is_feature_flag_on_api_v2_userinfo_check_is_feature_flag_on_get = Mock(
+        return_value=mock_ff_response
+    )
 
-    def get_latest_job_run(*args, **kwargs):
-        print("Called get_latest_job_run")
-        nonlocal i
-        i += 1
-        ret = Mock()
-        status = "RUNNING"
-        if i < 3:
-            status = "PENDING"
-        elif i < 5:
-            status = "AWAITING_CLUSTER_START"
-        ret.state.current_state = status
-        return ret
+    get_jobs_logs_from_storage_bucket_streaming_mock = CoroutineMock(
+        side_effect=[
+            ("1\n2\n3\n", "next_token", 10, False),
+            ("4\n5\n6\n", "next_token_2", 10, True),
+            ("7\n8\n9\n10\n", "next_token_3", 10, True),
+            ("", "next_token_3", 10, True),
+            ("", "next_token_3", 10, True),
+        ]
+    )
 
-    job_controller._get_job = Mock(side_effect=get_latest_job_run)  # type: ignore
-    job_controller._wait_for_job_running("fake_job_id")
-    assert i == 5
+    with patch(
+        "anyscale.controllers.job_controller._get_job_logs_from_storage_bucket_streaming",
+        new=get_jobs_logs_from_storage_bucket_streaming_mock,
+    ):
+        job_controller.logs(job_id=prod_job_id, should_follow=True)
+
+    get_jobs_logs_from_storage_bucket_streaming_mock.assert_has_awaits(
+        [
+            call(
+                ANY,
+                ANY,
+                job_run_id=last_job_run_id,
+                remove_escape_chars=False,
+                next_page_token=None,
+                cluster_journal_events_start_line=0,
+            ),
+            call(
+                ANY,
+                ANY,
+                job_run_id=last_job_run_id,
+                remove_escape_chars=False,
+                next_page_token="next_token",
+                cluster_journal_events_start_line=10,
+            ),
+            call(
+                ANY,
+                ANY,
+                job_run_id=last_job_run_id,
+                remove_escape_chars=False,
+                next_page_token="next_token_2",
+                cluster_journal_events_start_line=10,
+            ),
+            call(
+                ANY,
+                ANY,
+                job_run_id=last_job_run_id,
+                remove_escape_chars=False,
+                next_page_token="next_token_3",
+                cluster_journal_events_start_line=10,
+            ),
+            call(
+                ANY,
+                ANY,
+                job_run_id=last_job_run_id,
+                remove_escape_chars=False,
+                next_page_token="next_token_3",
+                cluster_journal_events_start_line=10,
+            ),
+        ]
+    )
+    job_controller.log.log.assert_has_calls(
+        [
+            call("1"),
+            call("2"),
+            call("3"),
+            call("4"),
+            call("5"),
+            call("6"),
+            call("7"),
+            call("8"),
+            call("9"),
+            call("10"),
+        ]
+    )
 
 
 def test_job_submit_parse_logic(mock_auth_api_client) -> None:
