@@ -1,6 +1,6 @@
 import json
 import time
-from unittest.mock import ANY, Mock, patch
+from unittest.mock import Mock, patch
 
 import pytest
 
@@ -66,7 +66,7 @@ def test_list_clouds_table(cloud_test_data: Cloud, mock_auth_api_client) -> None
     expected_rows = [
         "Clouds:",
         "ID          name          PROVIDER    REGION    CREDENTIALS",
-        f"{cloud_test_data.id}  {cloud_test_data.name}  {cloud_test_data.provider}    {cloud_test_data.region}    {cloud_test_data.credentials}",
+        f"{cloud_test_data.id}  {cloud_test_data.name}  {cloud_test_data.provider}         {cloud_test_data.region}    {cloud_test_data.credentials}",
     ]
     expected_output = "\n".join(expected_rows)
 
@@ -241,109 +241,3 @@ def test_list_sessions_json(
     controller.api_client.get_cloud_api_v2_clouds_cloud_id_get.assert_called_once_with(
         cloud_id=session_test_data.cloud_id
     )
-
-
-def test_list_ips_table(session_test_data: Session, mock_auth_api_client) -> None:
-    mock_project_definition = Mock()
-    mock_project_definition.root = "/some/directory"
-    mock_load_project_or_throw = Mock(return_value=mock_project_definition)
-
-    mock_get_project_id = Mock(return_value=session_test_data.project_id)
-
-    with patch.multiple(
-        "anyscale.controllers.list_controller",
-        load_project_or_throw=mock_load_project_or_throw,
-        get_project_id=mock_get_project_id,
-    ), patch.object(
-        ListController, "_get_head_and_worker_ips", return_value=("1.2.3.4", "")
-    ) as mock_get_head_and_worker_ip:
-        list_controller = ListController()
-        output = list_controller.list_ips(None, False, True)
-        expected_rows = [
-            "SESSION       IP ADDRESS    NODE TYPE",
-            f"{session_test_data.name}  1.2.3.4       head",
-        ]
-        expected_output = "\n".join(expected_rows)
-
-        assert output == expected_output
-
-    mock_load_project_or_throw.assert_called_once()
-    mock_get_project_id.assert_called_once_with(mock_project_definition.root)
-    list_controller.api_client.list_sessions_api_v2_sessions_get.assert_called_once_with(
-        project_id=session_test_data.project_id,
-        name=None,
-        state_filter=["AwaitingFileMounts", "Running"],
-        _request_timeout=ANY,
-    )
-    mock_get_head_and_worker_ip.assert_called_once_with(
-        session_name=session_test_data.name
-    )
-
-
-def test_list_ips_json(
-    cloud_test_data: Cloud,
-    project_test_data: Project,
-    session_test_data: Session,
-    mock_auth_api_client,
-) -> None:
-    mock_project_definition = Mock()
-    mock_project_definition.root = "/some/directory"
-    mock_load_project_or_throw = Mock(return_value=mock_project_definition)
-
-    mock_get_project_id = Mock(return_value=session_test_data.project_id)
-
-    with patch.multiple(
-        "anyscale.controllers.list_controller",
-        load_project_or_throw=mock_load_project_or_throw,
-        get_project_id=mock_get_project_id,
-    ), patch.object(
-        ListController, "_get_head_and_worker_ips", return_value=("1.2.3.4", "")
-    ) as mock_get_head_and_worker_ip:
-        list_controller = ListController()
-        output = list_controller.list_ips(None, True, True)
-        expected_output = json.dumps(
-            [
-                {
-                    "session": {
-                        "name": session_test_data.name,
-                        "status": "TASK_RUNNING",
-                    },
-                    "project": {"name": project_test_data.name},
-                    "cloud": {
-                        "id": cloud_test_data.id,
-                        "name": cloud_test_data.name,
-                        "provider": cloud_test_data.provider,
-                        "region": cloud_test_data.region,
-                        "credentials": cloud_test_data.credentials,
-                        "config": '{"max_stopped_instances": 0}',
-                        "state": "ACTIVE",
-                    },
-                    "head-ip": "1.2.3.4",
-                    "worker-ips": "",
-                }
-            ]
-        )
-
-        assert output == expected_output
-
-    mock_load_project_or_throw.assert_called_once()
-    mock_get_project_id.assert_called_once_with(mock_project_definition.root)
-    # TODO (jbai): code can be optimized, this api request is issued multiple times
-    list_controller.api_client.list_sessions_api_v2_sessions_get.assert_called_with(
-        project_id=session_test_data.project_id,
-        name=session_test_data.name,
-        state_filter=["AwaitingFileMounts", "Running"],
-        _request_timeout=ANY,
-    )
-    list_controller.api_client.get_session_commands_history_api_v2_session_commands_get.assert_called_once_with(
-        session_id=session_test_data.id
-    )
-    list_controller.api_client.get_project_api_v2_projects_project_id_get.assert_called_once_with(
-        project_id=session_test_data.project_id, _request_timeout=ANY,
-    )
-    list_controller.api_client.get_cloud_api_v2_clouds_cloud_id_get.assert_called_once_with(
-        cloud_id=session_test_data.cloud_id
-    )
-    mock_get_head_and_worker_ip.assert_called_once_with(
-        session_name=session_test_data.name
-    )
