@@ -649,7 +649,7 @@ class TestGetServiceID:
 
 
 def test_terminate_service(mock_auth_api_client):
-    """Test that v2 IDs go through v2 API, v1 through v1."""
+    """Test that terminate service"""
     service_controller = ServiceController()
 
     service_controller.terminate("service2_abc123")
@@ -657,24 +657,8 @@ def test_terminate_service(mock_auth_api_client):
         "service2_abc123",
     )
 
-    service_controller.job_controller._resolve_job_object = Mock(
-        return_value=Mock(id="service_abc123"),
-    )
-    service_controller.terminate("service_abc123")
-    service_controller.api_client.terminate_job_api_v2_decorated_ha_jobs_production_job_id_terminate_post.assert_called_once_with(
-        "service_abc123",
-    )
-
 
 class TestListServices:
-    def test_list_service_v1_with_id(self, mock_auth_api_client):
-        service_controller = ServiceController()
-        service_controller.list(service_id="service_v1_id")
-
-        service_controller.api_client.get_job_api_v2_decorated_ha_jobs_production_job_id_get.assert_called_once_with(
-            "service_v1_id",
-        )
-
     def test_list_service_v2_with_id(self, mock_auth_api_client):
         service_controller = ServiceController()
         service_controller.list(service_id="service2_id")
@@ -683,44 +667,6 @@ class TestListServices:
             "service2_id",
         )
 
-    def test_list_service_unexpected_error(self, mock_auth_api_client):
-        service_controller = ServiceController()
-        service_controller.list(service_id="service2_id")
-
-        service_controller.api_client.list_services_api_v2_services_v2_get.side_effect = Exception(
-            "Request failed! Unexpected exception!"
-        )
-
-        service_controller.list()
-
-        service_controller.job_controller.api_client.list_decorated_jobs_api_v2_decorated_ha_jobs_get.assert_not_called()
-
-    def test_list_service_error_fallback(self, mock_auth_api_client):
-        """
-        We fallback to list Services v1 if the execption indicates that the
-        FF is turned off for the user.
-        """
-        service_controller = ServiceController()
-        service_controller.list(service_id="service2_id")
-
-        service_controller.api_client.list_services_api_v2_services_v2_get.side_effect = Exception(
-            "Services v2 is not enabled for your organization."
-        )
-        service_controller.job_controller.api_client.list_decorated_jobs_api_v2_decorated_ha_jobs_get.return_value = DecoratedlistserviceapimodelListResponse(
-            results=[], metadata=Mock(next_paging_token=None),
-        )
-
-        service_controller.list()
-
-        service_controller.job_controller.api_client.list_decorated_jobs_api_v2_decorated_ha_jobs_get.assert_called_once_with(
-            creator_id=None,
-            name=None,
-            project_id=None,
-            type_filter="SERVICE",
-            archive_status="NOT_ARCHIVED",
-            count=10,
-        )
-
     @pytest.mark.parametrize("name", [None, "service_name"])
     @pytest.mark.parametrize("project_id", [None, "test_project_id"])
     @pytest.mark.parametrize("created_by_me", [True, False])
@@ -799,29 +745,6 @@ def test_rollback(mock_auth_api_client):
         "service2_abc123",
     )
 
-    with pytest.raises(
-        click.ClickException, match="rollback is only supported for v2 services"
-    ):
-        service_controller.rollback("service_abc123")
-
-
-def test_archive(mock_auth_api_client):
-    """Test that v1 IDs go through v1 API, v2 is rejected."""
-    service_controller = ServiceController()
-
-    with pytest.raises(
-        click.ClickException, match="archive is not currently supported for v2 services"
-    ):
-        service_controller.archive("service2_abc123")
-
-    service_controller.job_controller._resolve_job_object = Mock(
-        return_value=Mock(id="service_abc123"),
-    )
-    service_controller.archive("service_abc123")
-    service_controller.api_client.archive_job_api_v2_decorated_ha_jobs_production_job_id_archive_post.assert_called_once_with(
-        "service_abc123",
-    )
-
 
 @pytest.mark.parametrize("init_runtime_env", [None, {}, {"working_dir": "."}])
 def test_override_runtime_env_config_and_infer_project_id_v2(
