@@ -19,7 +19,7 @@ from anyscale.aws_iam_policies import (
     ANYSCALE_IAM_PERMISSIONS_SERVICE_STEADY_STATE,
     get_anyscale_aws_iam_assume_role_policy,
 )
-from anyscale.cli_logger import BlockLogger
+from anyscale.cli_logger import CloudSetupLogger
 from anyscale.client.openapi_client.models.create_cloud_resource import (
     CreateCloudResource,
 )
@@ -59,7 +59,20 @@ def _create_roles(anyscale_account: str):
     # Create & Configure the Dataplane Role
     dataplane_role_name = DEFAULT_RAY_IAM_ROLE + suffix
     dataplane_role = iam.create_role(
-        RoleName=dataplane_role_name, AssumeRolePolicyDocument="{}"
+        RoleName=dataplane_role_name,
+        AssumeRolePolicyDocument=json.dumps(
+            {
+                "Version": "2012-10-17",
+                "Statement": [
+                    {
+                        "Sid": "Allow",
+                        "Effect": "Allow",
+                        "Principal": {"Service": "ec2.amazonaws.com"},
+                        "Action": "sts:AssumeRole",
+                    }
+                ],
+            }
+        ),
     )["Role"]["Arn"]
 
     iam.attach_role_policy(
@@ -434,7 +447,7 @@ def test_verify_aws_vpc(
     result = verify_aws_vpc(
         cloud_resource=cloud_resource_mock,
         boto3_session=boto3.Session(region_name=region),
-        logger=BlockLogger(),
+        logger=CloudSetupLogger(),
     )
     assert result == expected_result
 
@@ -465,7 +478,7 @@ def test_verify_aws_subnets(capsys, is_private_network: bool):
         cloud_resource=cloud_resource_mock,
         region=region,
         is_private_network=is_private_network,
-        logger=BlockLogger(),
+        logger=CloudSetupLogger(),
     )
 
     _, stderr = capsys.readouterr()
@@ -493,7 +506,7 @@ def test_verify_aws_subnets_warn_about_not_assigning_public_ip_in_public_subnets
         cloud_resource=cloud_resource_mock,
         region=region,
         is_private_network=False,
-        logger=BlockLogger(),
+        logger=CloudSetupLogger(),
     )
 
     _, stderr = capsys.readouterr()
@@ -522,7 +535,7 @@ def test_verify_aws_subnets_vpc_subnet_mismatch(capsys):
         cloud_resource=cloud_resource_mock,
         region=region,
         is_private_network=False,
-        logger=BlockLogger(),
+        logger=CloudSetupLogger(),
     )
 
     _, stderr = capsys.readouterr()
@@ -546,7 +559,7 @@ def test_verify_aws_subnets_insufficient_subnets(capsys):
         cloud_resource=cloud_resource_mock,
         region=region,
         is_private_network=False,
-        logger=BlockLogger(),
+        logger=CloudSetupLogger(),
     )
     assert result is False
     _, stderr = capsys.readouterr()
@@ -570,7 +583,7 @@ def test_verify_aws_subnets_insufficient_azs(capsys):
         cloud_resource=cloud_resource_mock,
         region=region,
         is_private_network=False,
-        logger=BlockLogger(),
+        logger=CloudSetupLogger(),
     )
     assert result is False
     _, stderr = capsys.readouterr()
@@ -587,7 +600,7 @@ def test_verify_aws_subnets_no_subnets():
         cloud_resource=cloud_resource_mock,
         region="us-west-2",
         is_private_network=False,
-        logger=BlockLogger(),
+        logger=CloudSetupLogger(),
     )
     assert result is False
 
@@ -615,7 +628,9 @@ def test_aws_subnet_has_enough_capacity(
 
     assert (
         AWS_SUBNET_CAPACITY.verify_network_capacity(
-            cidr_block_str=subnet_cidr, resource_name="Subnet", logger=BlockLogger()
+            cidr_block_str=subnet_cidr,
+            resource_name="Subnet",
+            logger=CloudSetupLogger(),
         )
         == has_capacity
     )
@@ -731,7 +746,52 @@ def test_verify_aws_iam_roles_not_exist(cp_role_exist: bool, dp_role_exist: bool
         cloud_resource=cloud_resource_mock,
         boto3_session=boto3.Session(),
         anyscale_aws_account="fake_anyscale_aws_account",
-        logger=BlockLogger(),
+        logger=CloudSetupLogger(),
+        cloud_id="fake_cloud_id",
+    )
+
+
+@mock_iam
+def test_verify_aws_iam_data_plane_role_trust_policy():
+    """Tests that the dataplane role only passes validation if it
+    gives trust to AWS service EC2."""
+    cloud_resource_mock = generate_cloud_resource_mock_aws()
+    cp_role_arn, dp_role_arn = _create_roles("fake_anyscale_aws_account")
+    cloud_resource_mock.aws_iam_role_arns = [cp_role_arn, dp_role_arn]
+    mock_logger = Mock()
+    session = boto3.Session()
+    print(
+        verify_aws_iam_roles(
+            cloud_resource=cloud_resource_mock,
+            boto3_session=session,
+            anyscale_aws_account="fake_anyscale_aws_account",
+            logger=mock_logger,
+            cloud_id="fake_cloud_id",
+        )
+    )
+
+    iam = boto3.client("iam")
+    suffix = "".join(random.choices(string.ascii_lowercase, k=10))
+    dataplane_role_name = DEFAULT_RAY_IAM_ROLE + suffix
+    # create a dataplane role without assume role policy document:
+    dp_role_arn = iam.create_role(
+        RoleName=dataplane_role_name, AssumeRolePolicyDocument="{}"
+    )["Role"]["Arn"]
+
+    iam.attach_role_policy(
+        RoleName=dataplane_role_name, PolicyArn=AMAZON_ECR_READONLY_ACCESS_POLICY_ARN
+    )
+    iam.attach_role_policy(
+        RoleName=dataplane_role_name, PolicyArn=AMAZON_S3_FULL_ACCESS_POLICY_ARN
+    )
+    cloud_resource_mock.aws_iam_role_arns = [cp_role_arn, dp_role_arn]
+
+    # No AssumeRolePolicyDocument for role
+    assert not verify_aws_iam_roles(
+        cloud_resource=cloud_resource_mock,
+        boto3_session=session,
+        anyscale_aws_account="fake_anyscale_aws_account",
+        logger=mock_logger,
         cloud_id="fake_cloud_id",
     )
 
@@ -788,7 +848,7 @@ def test_verify_aws_iam_roles_different_account(capsys):
         cloud_resource=cloud_resource_mock,
         boto3_session=boto3.Session(),
         anyscale_aws_account="fake_anyscale_aws_account",
-        logger=BlockLogger(),
+        logger=CloudSetupLogger(),
         cloud_id="fake_cloud_id",
     )
 
@@ -826,7 +886,7 @@ def test_verify_aws_security_groups_exist_and_valid(
     result = verify_aws_security_groups(
         cloud_resource=cloud_resource_mock,
         boto3_session=boto3.Session(region_name=region),
-        logger=BlockLogger(),
+        logger=CloudSetupLogger(),
     )
 
     stdout, stderr = capsys.readouterr()
@@ -876,7 +936,7 @@ def test_verify_aws_security_groups_inbound_permissions(
     result = verify_aws_security_groups(
         cloud_resource=cloud_resource_mock,
         boto3_session=boto3.Session(region_name=region),
-        logger=BlockLogger(),
+        logger=CloudSetupLogger(),
     )
     stdout, stderr = capsys.readouterr()
     sys.stdout.write(stdout)
@@ -943,7 +1003,7 @@ def test_verify_aws_security_groups_multiple_security_groups(
     result = verify_aws_security_groups(
         cloud_resource=cloud_resource_mock,
         boto3_session=boto3.Session(region_name=region),
-        logger=BlockLogger(),
+        logger=CloudSetupLogger(),
     )
     stdout, stderr = capsys.readouterr()
     sys.stdout.write(stdout)
@@ -1050,7 +1110,7 @@ def test_verify_aws_s3_wrong_region(capsys):
             cloud_resource=cloud_resource_mock,
             boto3_session=boto3.Session(region_name=region),
             region=region,
-            logger=BlockLogger(),
+            logger=CloudSetupLogger(),
         )
 
     _, stderr = capsys.readouterr()
@@ -1110,11 +1170,11 @@ def test_verify_aws_efs(
     result = verify_aws_efs(
         cloud_resource=cloud_resource_mock,
         boto3_session=boto3.Session(region_name=region),
-        logger=BlockLogger(),
+        logger=CloudSetupLogger(),
     )
     _, stderr = capsys.readouterr()
     if warning:
-        assert re.search(r"does not contain network interface with subnet id", stderr)
+        assert re.search(r"does not contain a mount target with the subnet", stderr)
     if enable_backup:
         assert not re.search(r"backup policy is not enabled", stderr)
         assert not re.search(r"backup policy not found", stderr)
@@ -1170,7 +1230,7 @@ def test_verify_aws_efs_valid_ip(
     result = verify_aws_efs(
         cloud_resource=cloud_resource_mock,
         boto3_session=boto3.Session(region_name=region),
-        logger=BlockLogger(),
+        logger=CloudSetupLogger(),
     )
 
     stdout, stderr = capsys.readouterr()
@@ -1201,6 +1261,6 @@ def test_verify_aws_cloudformation_stack(
     result = verify_aws_cloudformation_stack(
         cloud_resource=cloud_resource_mock,
         boto3_session=boto3.Session(region_name=region),
-        logger=BlockLogger(),
+        logger=CloudSetupLogger(),
     )
     assert result == expected_result
