@@ -5,7 +5,7 @@ from click import ClickException
 import pytest
 import yaml
 
-from anyscale.cli_logger import BlockLogger
+from anyscale.cli_logger import BlockLogger, CloudSetupLogger
 from anyscale.utils.gcp_managed_setup_utils import (
     append_project_iam_policy,
     configure_firewall_policy,
@@ -44,7 +44,7 @@ def test_get_project_number(setup_mock_server, response, expected_error_message)
     if expected_error_message:
         with pytest.raises(ClickException) as e:
             get_project_number(factory, mock_project_id)
-            e.match(expected_error_message)
+        e.match(expected_error_message)
     else:
         assert get_project_number(factory, mock_project_id) == mock_project_name
 
@@ -99,7 +99,7 @@ def test_append_project_iam_policy(
     if expected_error_message:
         with pytest.raises(ClickException) as e:
             append_project_iam_policy(factory, mock_project_id, mock_role, mock_member)
-            e.match(expected_error_message)
+        e.match(expected_error_message)
     else:
         updated_policy = append_project_iam_policy(
             factory, mock_project_id, mock_role, mock_member
@@ -132,14 +132,17 @@ def test_enable_project_apis(setup_mock_server, response, expected_error_message
             "anyscale.utils.gcp_managed_setup_utils",
             wait_for_operation_completion=Mock(),
         ), pytest.raises(ClickException) as e:
-            enable_project_apis(factory, mock_project_id)
-            e.match(expected_error_message)
+            enable_project_apis(factory, mock_project_id, CloudSetupLogger())
+        e.match(expected_error_message)
     else:
         with patch.multiple(
             "anyscale.utils.gcp_managed_setup_utils",
             wait_for_operation_completion=Mock(),
         ):
-            assert enable_project_apis(factory, mock_project_id) is None
+            assert (
+                enable_project_apis(factory, mock_project_id, CloudSetupLogger())
+                is None
+            )
 
 
 @pytest.mark.parametrize(
@@ -167,7 +170,7 @@ def test_get_workload_identity_pool(
     if expected_error_message:
         with pytest.raises(ClickException) as e:
             get_workload_identity_pool(factory, mock_project_id, mock_pool_id)
-            e.match(expected_error_message)
+        e.match(expected_error_message)
     else:
         if pool_exists:
             assert (
@@ -202,7 +205,7 @@ def test_get_anyscale_gcp_access_service_acount(
     if expected_error_message:
         with pytest.raises(ClickException) as e:
             get_anyscale_gcp_access_service_acount(factory, mock_service_account)
-            e.match(expected_error_message)
+        e.match(expected_error_message)
     else:
         if service_account_exists:
             assert (
@@ -372,7 +375,7 @@ def test_delete_workload_identity_pool(
             delete_workload_identity_pool(
                 factory, mock_pool_name, BlockLogger(),
             )
-            e.match(expected_log_message)
+        e.match(expected_log_message)
     else:
         # not found
         with patch.multiple(
@@ -432,10 +435,10 @@ def test_wait_for_operation_completion(
                 service,
                 {"name": mock_operation_id},
                 "test",
-                timeout=1,
+                timeout=2,
                 polling_interval=10,
             )
-            e.match(expected_error_message)
+        e.match(expected_error_message)
     else:
         with patch.multiple(
             "anyscale.utils.gcp_managed_setup_utils.time",
@@ -557,7 +560,7 @@ def test_get_deployment_resources(setup_mock_server, responses, expected_error_m
                 mock_project_id,
                 mock_anyscale_access_service_account_name,
             )
-            e.match(expected_error_message)
+        e.match(expected_error_message)
     else:
         assert get_deployment_resources(
             factory,
@@ -608,7 +611,7 @@ def test_delete_gcp_deployment(setup_mock_server, responses, expected_error_mess
             wait_for_operation_completion=Mock(),
         ):
             delete_gcp_deployment(factory, mock_project_id, mock_deployment)
-            e.match(expected_error_message)
+        e.match(expected_error_message)
     else:
         with patch.multiple(
             "anyscale.utils.gcp_managed_setup_utils",
@@ -666,7 +669,7 @@ def test_update_deployment_with_bucket_only(
             update_deployment_with_bucket_only(
                 factory, mock_project_id, mock_deployment
             )
-            e.match(expected_error_message)
+        e.match(expected_error_message)
     else:
         with patch.multiple(
             "anyscale.utils.gcp_managed_setup_utils",
@@ -736,7 +739,7 @@ def test_remove_firewall_policy_associations(
             remove_firewall_policy_associations(
                 factory, mock_project_id, mock_firewall_policy
             )
-            e.match(expected_error_message)
+        e.match(expected_error_message)
     else:
         assert (
             remove_firewall_policy_associations(
