@@ -15,7 +15,7 @@ from google.iam.v1.policy_pb2 import Binding
 from googleapiclient.errors import HttpError
 import pytest
 
-from anyscale.cli_logger import BlockLogger
+from anyscale.cli_logger import CloudSetupLogger
 from anyscale.client.openapi_client.models import CreateCloudResourceGCP
 from anyscale.client.openapi_client.models.gcp_file_store_config import (
     GCPFileStoreConfig,
@@ -35,6 +35,7 @@ from anyscale.gcp_verification import (
     verify_gcp_project,
 )
 from anyscale.utils.network_verification import Direction, FirewallRule, Protocol
+from frontend.cli.anyscale.gcp_verification import _vpc_has_proxy_only_subnet
 
 
 _MOCK_GCP_PROJECT_ID = "anyscale-bridge-deadbeef"
@@ -131,7 +132,7 @@ def test_verify_gcp_networking(
 def test_gcp_subnet_has_enough_capacity(cidr: str, result: bool, log: str, capsys):
     subnet = Subnetwork(ip_cidr_range=cidr)
 
-    assert _gcp_subnet_has_enough_capacity(subnet, BlockLogger()) == result
+    assert _gcp_subnet_has_enough_capacity(subnet, CloudSetupLogger()) == result
 
     stdout, stderr = capsys.readouterr()
     sys.stdout.write(stdout)
@@ -141,6 +142,43 @@ def test_gcp_subnet_has_enough_capacity(cidr: str, result: bool, log: str, capsy
         assert re.search(log, stderr)
 
 
+@pytest.mark.parametrize(
+    ("responses", "expected"),
+    [
+        pytest.param(
+            {".*/subnetworks.*": [("200 OK", "proxy_only_subnet_present.json")],},
+            True,
+            id="ProxyOnlySubnetPresent",
+        ),
+        pytest.param(
+            {".*/subnetworks.*": [("200 OK", "proxy_only_subnet_missing.json")],},
+            False,
+            id="ProxyOnlySubnetMissing",
+        ),
+        pytest.param(
+            {".*/subnetworks.*": [("200 OK", "proxy_only_subnet_no_subnets.json")],},
+            False,
+            id="ProxyOnlySubnetNoSubnets",
+        ),
+        pytest.param(
+            {".*/subnetworks.*": [("200 OK", "proxy_only_subnet_wrong_vpc.json")],},
+            False,
+            id="ProxyOnlySubnetWrongVPC",
+        ),
+    ],
+)
+def test_vpc_has_proxy_only_subnet(setup_mock_server, responses, expected):
+    factory, tracker = setup_mock_server
+    tracker.reset(responses=responses)
+    assert (
+        _vpc_has_proxy_only_subnet(
+            factory, "myproject", "us-central1", Mock(self_link="myvpc")
+        )
+        == expected
+    )
+    assert len(tracker.seen_requests) == 1
+
+
 @pytest.mark.parametrize(
     "call_factory",
     [
@@ -318,6 +356,18 @@ def test_verify_gcp_access_service_account(
             )
 
 
+def test_verify_gcp_access_service_account_get_iam_policy_error(setup_mock_server):
+    factory, tracker = setup_mock_server
+    mock_resources = generate_gcp_cloud_mock_resources()
+    tracker.reset({".*": [("403 Forbidden", None),]})
+    assert (
+        verify_gcp_access_service_account(
+            factory, mock_resources, _MOCK_GCP_PROJECT_ID, _gcp_logger(yes=False)
+        )
+        is False
+    )
+
+
 @pytest.mark.parametrize(
     ("responses", "expected_result", "output"),
     [
@@ -370,7 +420,7 @@ def test_verify_firewall_policy(
             generate_gcp_cloud_mock_resources(),
             _MOCK_GCP_PROJECT_ID,
             _MOCK_GCP_CLOUD_REGION,
-            GCPLogger(BlockLogger(), "project", Mock()),
+            GCPLogger(CloudSetupLogger(), "project", Mock()),
         )
         == expected_result
     )
@@ -766,4 +816,4 @@ def test_check_bucket_region(setup_mock_server, region: str, file: str, result:
 
 
 def _gcp_logger(yes: bool = True) -> GCPLogger:
-    return GCPLogger(BlockLogger(), "project_abc", Mock(), yes=yes)
+    return GCPLogger(CloudSetupLogger(), "project_abc", Mock(), yes=yes)
