@@ -31,6 +31,7 @@ from anyscale.util import (
     sleep_till,
     str_data_size,
     updating_printer,
+    verify_data_plane_role_assume_role_policy,
 )
 from anyscale.utils.name_utils import gen_valid_name
 
@@ -291,7 +292,7 @@ def test_prepare_cloudformation_template():
     # cloud_formation_template.txt by commenting out these code. And use `bazelisk run`
     # to update the template (bazelisk run will not use the sandbox so that we have the
     # write permission).
-    # with open(f"{os.environ['HOME']}/product/cloud_formation_template.txt", 'w') as f:
+    # with open(f"{os.environ['HOME']}/product/frontend/cli/tests/cloud_formation_template.txt", 'w') as f:
     #     f.write(cfn_template)
 
     with open(
@@ -591,6 +592,79 @@ def test_contains_control_plane_role(assume_role_policy_document, expected_resul
     assert result == expected_result
 
 
+@pytest.mark.parametrize(
+    ("assume_role_policy_document", "expected_result"),
+    [
+        pytest.param(
+            {
+                "Version": "2012-10-17",
+                "Statement": [
+                    {
+                        "Effect": "Allow",
+                        "Principal": {"AWS": "000000"},
+                        "Action": "sts:AssumeRole",
+                    },
+                ],
+            },
+            False,
+        ),
+        pytest.param(
+            {
+                "Statement": [
+                    {
+                        "Effect": "Reject",
+                        "Principal": {
+                            "AWS": [
+                                "arn:aws:iam::other_account",
+                                "arn:aws:iam::000000:root",
+                            ]
+                        },
+                        "Action": "sts:AssumeRole",
+                    },
+                ],
+            },
+            False,
+        ),
+        pytest.param(
+            {
+                "Statement": [
+                    {
+                        "Effect": "Allow",
+                        "Principal": {
+                            "AWS": [
+                                "arn:aws:iam::other_account",
+                                "arn:aws:iam::another_account:root",
+                            ]
+                        },
+                        "Action": "sts:AssumeRole",
+                    },
+                ],
+            },
+            False,
+        ),
+        pytest.param(
+            {
+                "Statement": [
+                    {
+                        "Effect": "Allow",
+                        "Principal": {"Service": "ec2.amazonaws.com", "AWS": "000000"},
+                        "Action": "sts:AssumeRole",
+                    },
+                ],
+            },
+            True,
+        ),
+    ],
+)
+def test_verify_data_plane_role_assume_role_policy(
+    assume_role_policy_document, expected_result
+):
+    result = verify_data_plane_role_assume_role_policy(
+        assume_role_policy_document=assume_role_policy_document
+    )
+    assert result == expected_result
+
+
 def test_gen_valid_name():
     NAME_VALIDATION_REGEX_PATTERN = r"^[A-Za-z0-9_-]+$"
     name_without_prefiex = gen_valid_name()
